from typing import Literal, TypeAlias

DefImageDict: dict[str, int] = {
    "Scourge": 0,
    "Scourge Shadow": 1,
    "Scourge Birth": 2,
    "Scourge Death": 3,
    "Scourge Explosion": 4,
    "Broodling": 5,
    "Broodling Shadow": 6,
    "Broodling Remnants": 7,
    "Infested Terran": 8,
    "Infested Terran Shadow": 9,
    "Infested Terran Explosion": 10,
    "Guardian Cocoon": 11,
    "Guardian Cocoon Shadow": 12,
    "Defiler": 13,
    "Defiler Shadow": 14,
    "Defiler Birth": 15,
    "Defiler Remnants": 16,
    "Drone": 17,
    "Drone Shadow": 18,
    "Drone Birth": 19,
    "Drone Remnants": 20,
    "Egg": 21,
    "Egg Shadow": 22,
    "Egg Spawn": 23,
    "Egg Remnants": 24,
    "Guardian": 25,
    "Guardian Shadow": 26,
    "Guardian Birth": 27,
    "Guardian Death": 28,
    "Hydralisk": 29,
    "Hydralisk Shadow": 30,
    "Hydralisk Birth": 31,
    "Hydralisk Remnants": 32,
    "Infested Kerrigan": 33,
    "Infested Kerrigan Shadow": 34,
    "Needle Spines": 35,
    "Larva": 36,
    "Larva Remnants": 37,
    "Mutalisk": 38,
    "Mutalisk Shadow": 39,
    "Mutalisk Birth": 40,
    "Mutalisk Death": 41,
    "Overlord": 42,
    "Overlord Shadow": 43,
    "Overlord Birth": 44,
    "Overlord Death": 45,
    "Queen": 46,
    "Queen Shadow": 47,
    "Queen Death": 48,
    "Queen Birth": 49,
    "Ultralisk": 50,
    "Ultralisk Shadow": 51,
    "Ultralisk Birth": 52,
    "Ultralisk Remnants": 53,
    "Zergling": 54,
    "Zergling Shadow": 55,
    "Zergling Birth": 56,
    "Zergling Remnants": 57,
    "Zerg Air Death Explosion (Large)": 58,
    "Zerg Air Death Explosion (Small)": 59,
    "Zerg Building Explosion": 60,
    "Cerebrate": 61,
    "Cerebrate Shadow": 62,
    "Infested Command Center": 63,
    "Spawning Pool": 64,
    "Spawning Pool Shadow": 65,
    "Evolution Chamber": 66,
    "Evolution Chamber Shadow": 67,
    "Creep Colony": 68,
    "Creep Colony Shadow": 69,
    "Hatchery": 70,
    "Hatchery Shadow": 71,
    "Hive": 72,
    "Hive Shadow": 73,
    "Lair": 74,
    "Lair Shadow": 75,
    "Sunken Colony": 76,
    "Sunken Colony Shadow": 77,
    "Mature Chrysalis": 78,
    "Mature Chrysalis Shadow": 79,
    "Greater Spire": 80,
    "Greater Spire Shadow": 81,
    "Defiler Mound": 82,
    "Defiler Mound Shadow": 83,
    "Queen's Nest": 84,
    "Queen's Nest Shadow": 85,
    "Nydus Canal": 86,
    "Nydus Canal Shadow": 87,
    "Overmind With Shell": 88,
    "Overmind Remnants": 89,
    "Overmind Without Shell": 90,
    "Ultralisk Cavern": 91,
    "Ultralisk Cavern Shadow": 92,
    "Extractor": 93,
    "Extractor Shadow": 94,
    "Hydralisk Den": 95,
    "Hydralisk Den Shadow": 96,
    "Spire": 97,
    "Spire Shadow": 98,
    "Spore Colony": 99,
    "Spore Colony Shadow": 100,
    "Infested Command Center Overlay": 101,
    "Zerg Construction (Large)": 102,
    "Zerg Building Morph": 103,
    "Zerg Construction (Medium)": 104,
    "Zerg Construction (Small)": 105,
    "Zerg Building Construction Shadow": 106,
    "Zerg Building Spawn (Small)": 107,
    "Zerg Building Spawn (Medium)": 108,
    "Zerg Building Spawn (Large)": 109,
    "Zerg Building Rubble (Small)": 110,
    "Zerg Building Rubble (Large)": 111,
    "Carrier": 112,
    "Carrier Shadow": 113,
    "Carrier Engines": 114,
    "Carrier Warp Flash": 115,
    "Interceptor": 116,
    "Interceptor Shadow": 117,
    "Shuttle": 118,
    "Shuttle Shadow": 119,
    "Shuttle Engines": 120,
    "Shuttle Warp Flash": 121,
    "Dragoon": 122,
    "Dragoon Shadow": 123,
    "Dragoon Remnants": 124,
    "Dragoon Warp Flash": 125,
    "High Templar": 126,
    "High Templar Shadow": 127,
    "High Templar Warp Flash": 128,
    "Dark Templar (Hero)": 129,
    "Arbiter": 130,
    "Arbiter Shadow": 131,
    "Arbiter Engines": 132,
    "Arbiter Warp Flash": 133,
    "Archon Energy": 134,
    "Archon Being": 135,
    "Archon Swirl": 136,
    "Probe": 137,
    "Probe Shadow": 138,
    "Probe Warp Flash": 139,
    "Scout": 140,
    "Scout Shadow": 141,
    "Scout Engines": 142,
    "Scout Warp Flash": 143,
    "Reaver": 144,
    "Reaver Shadow": 145,
    "Reaver Warp Flash": 146,
    "Scarab": 147,
    "Observer": 148,
    "Observer Shadow": 149,
    "Observer Warp Flash": 150,
    "Zealot": 151,
    "Zealot Shadow": 152,
    "Zealot Death": 153,
    "Zealot Warp Flash": 154,
    "Templar Archives": 155,
    "Templar Archives Warp Flash": 156,
    "Templar Archives Shadow": 157,
    "Assimilator": 158,
    "Assimilator Warp Flash": 159,
    "Assimilator Shadow": 160,
    "Observatory": 161,
    "Observatory Warp Flash": 162,
    "Observatory Shadow": 163,
    "Citadel of Adun": 164,
    "Citadel of Adun Warp Flash": 165,
    "Citadel of Adun Shadow": 166,
    "Forge": 167,
    "Forge Overlay": 168,
    "Forge Warp Flash": 169,
    "Forge Shadow": 170,
    "Gateway": 171,
    "Gateway Warp Flash": 172,
    "Gateway Shadow": 173,
    "Cybernetics Core": 174,
    "Cybernetics Core Warp Flash": 175,
    "Cybernetics Core Overlay": 176,
    "Cybernetics Core Shadow": 177,
    "Khaydarin Crystal Formation": 178,
    "Nexus": 179,
    "Nexus Warp Flash": 180,
    "Nexus Overlay": 181,
    "Nexus Shadow": 182,
    "Photon Cannon": 183,
    "Photon Cannon Shadow": 184,
    "Photon Cannon Warp Flash": 185,
    "Arbiter Tribunal": 186,
    "Arbiter Tribunal Warp Flash": 187,
    "Arbiter Tribunal Shadow": 188,
    "Pylon": 189,
    "Pylon Warp Flash": 190,
    "Pylon Shadow": 191,
    "Robotics Facility": 192,
    "Robotics Facility Warp Flash": 193,
    "Robotics Facility Shadow": 194,
    "Shield Battery": 195,
    "Shield Battery Overlay": 196,
    "Shileld Battery Warp Flash": 197,
    "Shield Battery Shadow": 198,
    "Stargate": 199,
    "Stargate Overlay": 200,
    "Stargate Warp Flash": 201,
    "Stargate Shadow": 202,
    "Stasis Cell/Prison": 203,
    "Robotics Support Bay": 204,
    "Robotics Support Bay Warp Flash": 205,
    "Robotics Support Bay Shadow": 206,
    "Protoss Temple": 207,
    "Fleet Beacon": 208,
    "Fleet Beacon Warp Flash": 209,
    "Warp Texture": 210,
    "Warp Anchor": 211,
    "Fleet Beacon Shadow": 212,
    "Explosion1 (Small)": 213,
    "Explosion1 (Medium)": 214,
    "Explosion (Large)": 215,
    "Protoss Building Rubble (Small)": 216,
    "Protoss Building Rubble (Large)": 217,
    "Battlecruiser": 218,
    "Battlecruiser Shadow": 219,
    "Battlecruiser Engines": 220,
    "Civilian": 221,
    "Civilian Shadow": 222,
    "Dropship": 223,
    "Dropship Shadow": 224,
    "Dropship Engines": 225,
    "Firebat": 226,
    "Firebat Shadow": 227,
    "Ghost": 228,
    "Ghost Shadow": 229,
    "Ghost Remnants": 230,
    "Ghost Death": 231,
    "Nuke Beam": 232,
    "Nuke Target Dot": 233,
    "Goliath Base": 234,
    "Goliath Turret": 235,
    "Goliath Shadow": 236,
    "Sarah Kerrigan": 237,
    "Sarah Kerrigan Shadow": 238,
    "Marine": 239,
    "Marine Shadow": 240,
    "Marine Remnants": 241,
    "Marine Death": 242,
    "Wraith": 243,
    "Wraith Shadow": 244,
    "Wraith Engines": 245,
    "Scanner Sweep": 246,
    "SCV": 247,
    "SCV Shadow": 248,
    "SCV Glow": 249,
    "Siege Tank (Tank) Base": 250,
    "Siege Tank (Tank) Turret": 251,
    "Siege Tank (Tank) Base Shadow": 252,
    "Siege Tank (Siege) Base": 253,
    "Siege Tank (Siege) Turret": 254,
    "Siege Tank (Siege) Base Shadow": 255,
    "Vulture": 256,
    "Vulture Shadow": 257,
    "Spider Mine": 258,
    "Spider Mine Shadow": 259,
    "Science Vessel (Base)": 260,
    "Science Vessel (Turret)": 261,
    "Science Vessel Shadow": 262,
    "Terran Academy": 263,
    "Academy Overlay": 264,
    "Academy Shadow": 265,
    "Barracks": 266,
    "Barracks Shadow": 267,
    "Armory": 268,
    "Armory Overlay": 269,
    "Armory Shadow": 270,
    "Comsat Station": 271,
    "Comsat Station Connector": 272,
    "Comsat Station Overlay": 273,
    "Comsat Station Shadow": 274,
    "Command Center": 275,
    "Command Center Overlay": 276,
    "Command Center Shadow": 277,
    "Supply Depot": 278,
    "Supply Depot Overlay": 279,
    "Supply Depot Shadow": 280,
    "Control Tower": 281,
    "Control Tower Connector": 282,
    "Control Tower Overlay": 283,
    "Control Tower Shadow": 284,
    "Factory": 285,
    "Factory Overlay": 286,
    "Factory Shadow": 287,
    "Covert Ops": 288,
    "Covert Ops Connector": 289,
    "Covert Ops Overlay": 290,
    "Covert Ops Shadow": 291,
    "Ion Cannon": 292,
    "Machine Shop": 293,
    "Machine Shop Connector": 294,
    "Machine Shop Shadow": 295,
    "Missile Turret (Base)": 296,
    "Missile Turret (Turret)": 297,
    "Missile Turret (Base) Shadow": 298,
    "Crashed Batlecruiser": 299,
    "Crashed Battlecruiser Shadow": 300,
    "Physics Lab": 301,
    "Physics Lab Connector": 302,
    "Physics Lab Shadow": 303,
    "Bunker": 304,
    "Bunker Shadow": 305,
    "Bunker Overlay": 306,
    "Refinery": 307,
    "Refinery Shadow": 308,
    "Science Facility": 309,
    "Science Facility Overlay": 310,
    "Science Facility Shadow": 311,
    "Nuclear Silo": 312,
    "Nuclear Silo Connector": 313,
    "Nuclear Silo Overlay": 314,
    "Nuclear Silo Shadow": 315,
    "Nuclear Missile": 316,
    "Nuclear Missile Shadow": 317,
    "Nuke Hit": 318,
    "Starport": 319,
    "Starport Overlay": 320,
    "Starport Shadow": 321,
    "Engineering Bay": 322,
    "Engineering Bay Overlay": 323,
    "Engineering Bay Shadow": 324,
    "Terran Construction (Large)": 325,
    "Terran Construction (Large) Shadow": 326,
    "Terran Construction (Medium)": 327,
    "Terran Construction (Medium) Shadow": 328,
    "Addon Construction": 329,
    "Terran Construction (Small)": 330,
    "Terran Construction (Small) Shadow": 331,
    "Explosion2 (Small)": 332,
    "Explosion2 (Medium)": 333,
    "Building Explosion (Large)": 334,
    "Terran Building Rubble (Small)": 335,
    "Terran Building Rubble (Large)": 336,
    "Dark Swarm": 337,
    "Ragnasaur (Ash)": 338,
    "Ragnasaur (Ash) Shadow": 339,
    "Rhynadon (Badlands)": 340,
    "Rhynadon (Badlands) Shadow": 341,
    "Bengalaas (Jungle)": 342,
    "Bengalaas (Jungle) Shadow": 343,
    "Vespene Geyser": 344,
    "Vespene Geyser2": 345,
    "Vespene Geyser Shadow": 346,
    "Mineral Field Type1": 347,
    "Mineral Field Type1 Shadow": 348,
    "Mineral Field Type2": 349,
    "Mineral Field Type2 Shadow": 350,
    "Mineral Field Type3": 351,
    "Mineral Field Type3 Shadow": 352,
    "Independent Starport (Unused)": 353,
    "Zerg Beacon": 354,
    "Zerg Beacon Overlay": 355,
    "Terran Beacon": 356,
    "Terran Beacon Overlay": 357,
    "Protoss Beacon": 358,
    "Protoss Beacon Overlay": 359,
    "Magna Pulse (Unused)": 360,
    "Lockdown Field (Small)": 361,
    "Lockdown Field (Medium)": 362,
    "Lockdown Field (Large)": 363,
    "Stasis Field Hit": 364,
    "Stasis Field (Small)": 365,
    "Stasis Field (Medium)": 366,
    "Stasis Field (Large)": 367,
    "Recharge Shields (Small)": 368,
    "Recharge Shields (Medium)": 369,
    "Recharge Shields (Large)": 370,
    "Defensive Matrix Front (Small)": 371,
    "Defensive Matrix Front (Medium)": 372,
    "Defensive Matrix Front (Large)": 373,
    "Defensive Matrix Back (Small)": 374,
    "Defensive Matrix Back (Medium)": 375,
    "Defensive Matrix Back (Large)": 376,
    "Defensive Matrix Hit (Small)": 377,
    "Defensive Matrix Hit (Medium)": 378,
    "Defensive Matrix Hit (Large)": 379,
    "Irradiate (Small)": 380,
    "Irradiate (Medium)": 381,
    "Irradiate (Large)": 382,
    "Ensnare Cloud": 383,
    "Ensnare Overlay (Small)": 384,
    "Ensnare Overlay (Medium)": 385,
    "Ensnare Overlay (Large)": 386,
    "Plague Cloud": 387,
    "Plague Overlay (Small)": 388,
    "Plague Overlay (Medium)": 389,
    "Plague Overlay (Large)": 390,
    "Recall Field": 391,
    "Flag": 392,
    "Young Chrysalis": 393,
    "Psi Emitter": 394,
    "Data Disc": 395,
    "Khaydarin Crystal": 396,
    "Mineral Chunk Type1": 397,
    "Mineral Chunk Type2": 398,
    "Protoss Gas Orb Type1": 399,
    "Protoss Gas Orb Type2": 400,
    "Zerg Gas Sac Type1": 401,
    "Zerg Gas Sac Type2": 402,
    "Terran Gas Tank Type1": 403,
    "Terran Gas Tank Type2": 404,
    "Mineral Chunk Shadow": 405,
    "Protoss Gas Orb Shadow": 406,
    "Zerg Gas Sac Shadow": 407,
    "Terran Gas Tank Shadow": 408,
    "Data Disk Shadow (Ground)": 409,
    "Data Disk Shadow (Carried)": 410,
    "Flag Shadow (Ground)": 411,
    "Flag Shadow (Carried)": 412,
    "Crystal Shadow (Ground)": 413,
    "Crystal Shadow (Carried)": 414,
    "Young Chrysalis Shadow (Ground)": 415,
    "Young Chrysalis Shadow (Carried)": 416,
    "Psi Emitter Shadow (Ground)": 417,
    "Psi Emitter Shadow (Carried)": 418,
    "Acid Spray (Unused)": 419,
    "Plasma Drip (Unused)": 420,
    "FlameThrower": 421,
    "Longbolt/Gemini Missiles Trail": 422,
    "Burrowing Dust": 423,
    "Shield Overlay": 424,
    "Small Explosion (Unused)": 425,
    "Double Explosion": 426,
    "Phase Disruptor Hit": 427,
    "Nuclear Missile Death": 428,
    "Spider Mine Death": 429,
    "Vespene Geyser Smoke1": 430,
    "Vespene Geyser Smoke2": 431,
    "Vespene Geyser Smoke3": 432,
    "Vespene Geyser Smoke4": 433,
    "Vespene Geyser Smoke5": 434,
    "Vespene Geyser Smoke1 Overlay": 435,
    "Vespene Geyser Smoke2 Overlay": 436,
    "Vespene Geyser Smoke3 Overlay": 437,
    "Vespene Geyser Smoke4 Overlay": 438,
    "Vespene Geyser Smoke5 Overlay": 439,
    "Fragmentation Grenade Hit": 440,
    "Grenade Shot Smoke": 441,
    "Anti-Matter Missile Hit": 442,
    "Scarab/Anti-Matter Missile Overlay": 443,
    "Scarab Hit": 444,
    "Cursor Marker": 445,
    "Battlecruiser Attack Overlay": 446,
    "Burst Lasers Hit": 447,
    "Burst Lasers Overlay (Unused)": 448,
    "High Templar Glow": 449,
    "Flames1 Type1 (Small)": 450,
    "Flames1 Type2 (Small)": 451,
    "Flames1 Type3 (Small)": 452,
    "Flames2 Type3 (Small)": 453,
    "Flames3 Type3 (Small)": 454,
    "Flames4 Type3 (Small)": 455,
    "Flames5 Type3 (Small)": 456,
    "Flames6 Type3 (Small)": 457,
    "Bleeding Variant1 Type1 (Small)": 458,
    "Bleeding Variant1 Type2 (Small)": 459,
    "Bleeding Variant1 Type3 (Small)": 460,
    "Bleeding Variant1 Type4 (Small)": 461,
    "Bleeding Variant2 Type1 (Small)": 462,
    "Bleeding Variant2 Type2 (Small)": 463,
    "Bleeding Variant2 Type3 (Small)": 464,
    "Bleeding Variant2 Type4 (Small)": 465,
    "Flames2 Type1 (Small)": 466,
    "Flames2 Type2 (Small)": 467,
    "Flames7 Type3 (Small)": 468,
    "Flames3 Type1 (Small)": 469,
    "Flames3 Type2 (Small)": 470,
    "Flames8 Type3 (Small)": 471,
    "Flames1 Type1 (Large)": 472,
    "Flames1 Type2 (Large)": 473,
    "Flames1 Type3 (Large)": 474,
    "Flames2 Type3 (Large)": 475,
    "Flames3 Type3 (Large)": 476,
    "Flames4 Type3 (Large)": 477,
    "Flames5 Type3 (Large)": 478,
    "Flames6 Type3 (Large)": 479,
    "Bleeding Variant1 Type1 (Large)": 480,
    "Bleeding Variant1 Type2 (Large)": 481,
    "Bleeding Variant1 Type3 (Large)": 482,
    "Bleeding Variant1 Type4 (Large)": 483,
    "Bleeding Variant2 Type1 (Large)": 484,
    "Bleeding Variant2 Type3 (Large)": 485,
    "Bleeding Variant3 Type3 (Large)": 486,
    "Bleeding Variant2 Type4 (Large)": 487,
    "Flames2 Type1 (Large)": 488,
    "Flames2 Type2 (Large)": 489,
    "Flames7 Type3 (Large)": 490,
    "Flames3 Type1 (Large)": 491,
    "Flames3 Type2 (Large)": 492,
    "Flames8 Type3 (Large)": 493,
    "Building Landing Dust Type1": 494,
    "Building Landing Dust Type2": 495,
    "Building Landing Dust Type3": 496,
    "Building Landing Dust Type4": 497,
    "Building Landing Dust Type5": 498,
    "Building Lifting Dust Type1": 499,
    "Building Lifting Dust Type2": 500,
    "Building Lifting Dust Type3": 501,
    "Building Lifting Dust Type4": 502,
    "White Circle": 503,
    "Needle Spine Hit": 504,
    "Plasma Drip Hit (Unused)": 505,
    "Sunken Colony Tentacle": 506,
    "Venom (Unused Zerg Weapon)": 507,
    "Venom Hit (Unused)": 508,
    "Acid Spore": 509,
    "Acid Spore Hit": 510,
    "Glave Wurm": 511,
    "Glave Wurm/Seeker Spores Hit": 512,
    "Glave Wurm Trail": 513,
    "Seeker Spores Overlay": 514,
    "Seeker Spores": 515,
    "Queen Spell Holder": 516,
    "Consume": 517,
    "Guardian Attack Overlay": 518,
    "Dual Photon Blasters Hit": 519,
    "Particle Beam Hit": 520,
    "Anti-Matter Missile": 521,
    "Pulse Cannon": 522,
    "Phase Disruptor": 523,
    "STA/STS Photon Cannon Overlay": 524,
    "Psionic Storm": 525,
    "Fusion Cutter Hit": 526,
    "Gauss Rifle Hit": 527,
    "Gemini Missiles": 528,
    "Lockdown/LongBolt/Hellfire Missile": 529,
    "Gemini Missiles Explosion": 530,
    "C-10 Canister Rifle Hit": 531,
    "Fragmentation Grenade": 532,
    "Arclite Shock Cannon Hit": 533,
    "ATS/ATA Laser Battery": 534,
    "Burst Lasers": 535,
    "Siege Tank(Tank) Turret Attack Overlay": 536,
    "Siege Tank(Siege) Turret Attack Overlay": 537,
    "Science Vessel Overlay (Part1)": 538,
    "Science Vessel Overlay (Part2)": 539,
    "Science Vessel Overlay (Part3)": 540,
    "Yamato Gun": 541,
    "Yamato Gun Trail": 542,
    "Yamato Gun Overlay": 543,
    "Yamato Gun Hit": 544,
    "Hallucination Hit": 545,
    "Scanner Sweep Hit": 546,
    "Archon Birth (Unused)": 547,
    "Psionic Shockwave Hit": 548,
    "Archon Beam": 549,
    "Psionic Storm Part1": 550,
    "Psionic Storm Part2": 551,
    "Psionic Storm Part3": 552,
    "Psionic Storm Part4": 553,
    "EMP Shockwave Missile": 554,
    "EMP Shockwave Hit (Part1)": 555,
    "EMP Shockwave Hit (Part2)": 556,
    "Hallucination Death1": 557,
    "Hallucination Death2": 558,
    "Hallucination Death3": 559,
    "Circle Marker1": 560,
    "Selection Circle (22pixels)": 561,
    "Selection Circle (32pixels)": 562,
    "Selection Circle (48pixels)": 563,
    "Selection Circle (62pixels)": 564,
    "Selection Circle (72pixels)": 565,
    "Selection Circle (94pixels)": 566,
    "Selection Circle (110pixels)": 567,
    "Selection Circle (122pixels)": 568,
    "Selection Circle (146pixels)": 569,
    "Selection Circle (224pixels)": 570,
    "Selection Circle Dashed (22pixels)": 571,
    "Selection Circle Dashed (32pixels)": 572,
    "Selection Circle Dashed (48pixels)": 573,
    "Selection Circle Dashed (62pixels)": 574,
    "Selection Circle Dashed (72pixels)": 575,
    "Selection Circle Dashed (94pixels)": 576,
    "Selection Circle Dashed (110pixels)": 577,
    "Selection Circle Dashed (122pixels)": 578,
    "Selection Circle Dashed (146pixels)": 579,
    "Selection Circle Dashed (224pixels)": 580,
    "Circle Marker2": 581,
    "Map Revealer": 582,
    "Circle Marker3": 583,
    "Psi Field1 (Right Upper)": 584,
    "Psi Field1 (Right Lower)": 585,
    "Psi Field2 (Right Upper)": 586,
    "Psi Field2 (Right Lower)": 587,
    "Start Location": 588,
    "2/38 Ash": 589,
    "2/38 Ash Shadow": 590,
    "2/39 Ash": 591,
    "2/39 Ash Shadow": 592,
    "2/41 Ash": 593,
    "2/41 Ash Shadow": 594,
    "2/40 Ash": 595,
    "2/40 Ash Shadow": 596,
    "2/42 Ash": 597,
    "2/42 Ash Shadow": 598,
    "2/43 Ash": 599,
    "2/44 Ash": 600,
    "2/1 Ash": 601,
    "2/4 Ash": 602,
    "2/5 Ash": 603,
    "2/30 Ash": 604,
    "2/28 Ash": 605,
    "2/29 Ash": 606,
    "4/1 Ash": 607,
    "4/2 Ash": 608,
    "4/3 Ash": 609,
    "4/56 Jungle": 610,
    "4/56 Jungle Shadow": 611,
    "4/57 Jungle": 612,
    "4/57 Jungle Shadow": 613,
    "4/58 Jungle": 614,
    "4/58 Jungle Shadow": 615,
    "4/59 Jungle": 616,
    "4/59 Jungle Shadow": 617,
    "9/5 Jungle": 618,
    "9/5 Jungle Shadow": 619,
    "9/6 Jungle": 620,
    "9/6 Jungle Shadow": 621,
    "9/7 Jungle": 622,
    "9/7 Jungle Shadow": 623,
    "4/51 Jungle": 624,
    "4/51 Jungle Shadow": 625,
    "4/52 Jungle": 626,
    "4/52 Jungle Shadow": 627,
    "4/54 Jungle": 628,
    "4/54 Jungle Shadow": 629,
    "4/53 Jungle": 630,
    "4/53 Jungle Shadow": 631,
    "9/1 Jungle": 632,
    "9/1 Jungle Shadow": 633,
    "9/2 Jungle": 634,
    "9/2 Jungle Shadow": 635,
    "9/3 Jungle": 636,
    "9/3 Jungle Shadow": 637,
    "9/4 Jungle": 638,
    "9/4 Jungle Shadow": 639,
    "4/12 Jungle": 640,
    "4/13 Jungle": 641,
    "4/1 Jungle": 642,
    "4/3 Jungle": 643,
    "4/2 Jungle": 644,
    "4/5 Jungle": 645,
    "4/4 Jungle": 646,
    "4/9 Jungle": 647,
    "4/10 Jungle": 648,
    "5/5 Jungle": 649,
    "5/7 Jungle": 650,
    "5/6 Jungle": 651,
    "5/9 Jungle": 652,
    "5/8 Jungle": 653,
    "4/6 Jungle": 654,
    "4/7 Jungle": 655,
    "4/17 Jungle": 656,
    "13/4 Jungle": 657,
    "11/5 Jungle": 658,
    "11/6 Jungle": 659,
    "11/7 Jungle": 660,
    "11/8 Jungle": 661,
    "11/10 Jungle": 662,
    "11/11 Jungle": 663,
    "11/12 Jungle": 664,
    "7/4 Platform": 665,
    "7/4 Platform Shadow": 666,
    "7/5 Platform": 667,
    "7/5 Platform Shadow": 668,
    "7/6 Platform": 669,
    "7/6 Platform Shadow": 670,
    "7/1 Platform": 671,
    "7/1 Platform Shadow": 672,
    "7/2 Platform": 673,
    "7/2 Platform Shadow": 674,
    "7/3 Platform": 675,
    "7/3 Platform Shadow": 676,
    "7/9 Platform": 677,
    "7/10 Platform": 678,
    "7/8 Platform": 679,
    "7/7 Platform": 680,
    "7/26 Platform": 681,
    "7/24 Platform": 682,
    "7/28 Platform": 683,
    "7/27 Platform": 684,
    "7/25 Platform": 685,
    "7/29 Platform": 686,
    "7/30 Platform": 687,
    "7/31 Platform": 688,
    "12/1 Platform": 689,
    "9/27 Platform": 690,
    "5/54 Badlands": 691,
    "5/54 Badlands Shadow": 692,
    "5/55 Badlands": 693,
    "5/55 Badlands Shadow": 694,
    "5/56 Badlands": 695,
    "5/56 Badlands Shadow": 696,
    "5/57 Badlands": 697,
    "5/57 Badlands Shadow": 698,
    "6/16 Badlands": 699,
    "6/17 Badlands": 700,
    "6/20 Badlands": 701,
    "6/21 Badlands": 702,
    "5/10 Badlands": 703,
    "5/50 Badlands": 704,
    "5/50 Badlands Shadow": 705,
    "5/52 Badlands": 706,
    "5/52 Badlands Shadow": 707,
    "5/53 Badlands": 708,
    "5/53 Badlands Shadow": 709,
    "5/51 Badlands": 710,
    "5/51 Badlands Shadow": 711,
    "6/3 Badlands": 712,
    "11/3 Badlands": 713,
    "11/8 Badlands": 714,
    "11/6 Badlands": 715,
    "11/7 Badlands": 716,
    "11/9 Badlands": 717,
    "11/10 Badlands": 718,
    "11/11 Badlands": 719,
    "11/12 Badlands": 720,
    "11/13 Badlands": 721,
    "11/14 Badlands": 722,
    "1/13 Badlands": 723,
    "1/9 Badlands": 724,
    "1/11 Badlands": 725,
    "1/14 Badlands": 726,
    "1/10 Badlands": 727,
    "1/12 Badlands": 728,
    "1/15 Badlands": 729,
    "1/7 Badlands": 730,
    "1/5 Badlands": 731,
    "1/16 Badlands": 732,
    "1/8 Badlands": 733,
    "1/6 Badlands": 734,
    "Floor Gun Trap": 735,
    "Floor Missile Trap": 736,
    "Floor Missile Trap Turret": 737,
    "Wall Missile Trap": 738,
    "Wall Missile Trap2": 739,
    "Wall Flame Trap": 740,
    "Wall Flame Trap2": 741,
    "Left Upper Level Door": 742,
    "Right Upper Level Door": 743,
    "4/15 Installation1": 744,
    "4/15 Installation2": 745,
    "3/9 Installation": 746,
    "3/10 Installation": 747,
    "3/11 Installation": 748,
    "3/12 Installation": 749,
    "Substructure Left Door": 750,
    "Substructure Right Door": 751,
    "3/1 Installation": 752,
    "3/2 Installation": 753,
    "Substructure Opening Hole": 754,
    "7/21 Twilight": 755,
    "Unknown Twilight": 756,
    "7/13 Twilight": 757,
    "7/14 Twilight": 758,
    "7/16 Twilight": 759,
    "7/15 Twilight": 760,
    "7/19 Twilight": 761,
    "7/20 Twilight": 762,
    "7/17 Twilight": 763,
    "6/1 Twilight": 764,
    "6/2 Twilight": 765,
    "6/3 Twilight": 766,
    "6/4 Twilight": 767,
    "6/5 Twilight": 768,
    "8/3 Twilight1": 769,
    "8/3 Twilight2": 770,
    "9/29 Ice": 771,
    "9/29 Ice Shadow": 772,
    "9/28 Ice": 773,
    "9/28 Ice Shadow": 774,
    "12/38 Ice": 775,
    "12/38 Ice Shadow": 776,
    "12/37 Ice": 777,
    "12/37 Ice Shadow": 778,
    "12/33 Ice1": 779,
    "12/33 Ice1 Shadow": 780,
    "9/21 Ice": 781,
    "9/21 Ice Shadow": 782,
    "9/15 Ice": 783,
    "9/15 Ice Shadow": 784,
    "9/16 Ice": 785,
    "9/16 Ice Shadow": 786,
    "Unknown787": 787,
    "Unknown788": 788,
    "12/9 Ice1": 789,
    "12/10 Ice1": 790,
    "9/24 Ice": 791,
    "9/24 Ice Shadow": 792,
    "9/23 Ice": 793,
    "9/23 Ice Shadow": 794,
    "Unknown795": 795,
    "Unknown Ice Shadow": 796,
    "12/7 Ice": 797,
    "12/7 Ice Shadow": 798,
    "12/8 Ice": 799,
    "12/8 Ice Shadow": 800,
    "12/9 Ice2": 801,
    "12/9 Ice2 Shadow": 802,
    "12/10 Ice2": 803,
    "12/10 Ice2 Shadow": 804,
    "12/40 Ice": 805,
    "12/40 Ice Shadow": 806,
    "12/41 Ice": 807,
    "12/41 Ice Shadow": 808,
    "12/42 Ice": 809,
    "12/42 Ice Shadow": 810,
    "12/5 Ice": 811,
    "12/5 Ice Shadow": 812,
    "12/6 Ice": 813,
    "12/6 Ice Shadow": 814,
    "12/36 Ice": 815,
    "12/36 Ice Shadow": 816,
    "12/32 Ice": 817,
    "12/32 Ice Shadow": 818,
    "12/33 Ice2": 819,
    "12/33 Ice2 Shadow": 820,
    "12/34 Ice": 821,
    "12/34 Ice Shadow": 822,
    "12/24 Ice1": 823,
    "12/24 Ice1 Shadow": 824,
    "12/25 Ice1": 825,
    "12/25 Ice1 Shadow": 826,
    "12/30 Ice1": 827,
    "12/30 Ice1 Shadow": 828,
    "12/31 Ice": 829,
    "12/31 Ice Shadow": 830,
    "12/20 Ice": 831,
    "12/30 Ice2": 832,
    "12/30 Ice2 Shadow": 833,
    "9/22 Ice": 834,
    "9/22 Ice Shadow": 835,
    "12/24 Ice2": 836,
    "12/24 Ice2 Shadow": 837,
    "12/25 Ice2": 838,
    "12/25 Ice2 Shadow": 839,
    "Unknown840": 840,
    "4/1 Ice": 841,
    "6/1 Ice": 842,
    "5/6 Ice": 843,
    "5/6 Ice Shadow": 844,
    "5/7 Ice": 845,
    "5/7 Ice Shadow": 846,
    "5/8 Ice": 847,
    "5/8 Ice Shadow": 848,
    "5/9 Ice": 849,
    "5/9 Ice Shadow": 850,
    "10/10 Desert1": 851,
    "10/12 Desert1": 852,
    "10/12 Desert1 Shadow": 853,
    "10/8 Desert1": 854,
    "10/8 Desert1 Shadow": 855,
    "10/9 Desert1": 856,
    "10/9 Desert1 Shadow": 857,
    "6/10 Desert": 858,
    "6/10 Desert Shadow": 859,
    "6/13 Desert1": 860,
    "6/13 Desert1 Shadow": 861,
    "Unknown Desert": 862,
    "Unknown Desert Shadow": 863,
    "10/12 Desert2": 864,
    "10/12 Desert2 Shadow": 865,
    "10/9 Desert2": 866,
    "10/9 Desert2 Shadow": 867,
    "10/10 Desert2": 868,
    "10/10 Desert2 Shadow": 869,
    "10/11 Desert": 870,
    "10/11 Desert Shadow": 871,
    "10/14 Desert": 872,
    "10/14 Desert Shadow": 873,
    "10/41 Desert": 874,
    "10/41 Desert Shadow": 875,
    "10/39 Desert": 876,
    "1/39 Desert Shadow": 877,
    "10/8 Desert2": 878,
    "10/8 Desert2 Shadow": 879,
    "10/6 Desert": 880,
    "10/7 Desert": 881,
    "10/7 Desert Shadow": 882,
    "4/6 Desert": 883,
    "4/6 Desert Shadow": 884,
    "4/11 Desert": 885,
    "4/11 Desert Shadow": 886,
    "4/10 Desert": 887,
    "4/10 Desert Shadow": 888,
    "4/9 Desert": 889,
    "4/7 Desert": 890,
    "4/7 Desert Shadow": 891,
    "4/12 Desert": 892,
    "4/12 Desert Shadow": 893,
    "4/8 Desert": 894,
    "4/13 Desert": 895,
    "4/13 Desert Shadow": 896,
    "4/17 Desert": 897,
    "4/15 Desert1": 898,
    "4/15 Desert1 Shadow": 899,
    "10/23 Desert": 900,
    "10/23 Desert Shadow": 901,
    "10/5 Desert": 902,
    "10/5 Desert Shadow": 903,
    "6/13 Desert2": 904,
    "6/13 Desert2 Shadow": 905,
    "6/20 Desert": 906,
    "4/15 Desert2": 907,
    "4/15 Desert2 Shadow": 908,
    "8/23 Desert": 909,
    "8/23 Desert Shadow": 910,
    "12/1 Desert Overlay": 911,
    "11/3 Desert": 912,
    "Unknown913": 913,
    "Lurker Egg": 914,
    "Devourer": 915,
    "Devourer Shadow": 916,
    "Devourer Birth": 917,
    "Devourer Death": 918,
    "Lurker Birth": 919,
    "Lurker Remnants": 920,
    "Lurker": 921,
    "Lurker Shadow": 922,
    "Overmind Cocoon": 923,
    "Overmind Cocoon Shadow": 924,
    "Dark Archon Energy": 925,
    "Dark Archon Being": 926,
    "Dark Archon Swirl": 927,
    "Dark Archon Death": 928,
    "Corsair": 929,
    "Corsair Shadow": 930,
    "Corsair Engines": 931,
    "Neutron Flare Overlay (Unused)": 932,
    "Dark Templar (Unit)": 933,
    "Warp Gate": 934,
    "Warp Gate Shadow": 935,
    "Warp Gate Overlay": 936,
    "Xel'Naga Temple": 937,
    "Xel'Naga Temple Shadow": 938,
    "Valkyrie": 939,
    "Valkyrie Shadow": 940,
    "Valkyrie Engines": 941,
    "Valkyrie Engines2 (Unused)": 942,
    "Valkyrie Afterburners (Unused)": 943,
    "Medic": 944,
    "Medic Shadow": 945,
    "Medic Remnants": 946,
    "Psi Disrupter": 947,
    "Psi Disrupter Shadow": 948,
    "Power Generator": 949,
    "Power Generator Shadow": 950,
    "Disruption Web": 951,
    "Scantid (Desert)": 952,
    "Scantid (Desert) Shadow": 953,
    "Kakaru (Twilight)": 954,
    "Kakaru (Twilight) Shadow": 955,
    "Ursadon (Ice)": 956,
    "Ursadon (Ice) Shadow": 957,
    "Uraj": 958,
    "Khalis": 959,
    "Halo Rockets Trail": 960,
    "Subterranean Spines": 961,
    "Corrosive Acid Shot": 962,
    "Corrosive Acid Hit": 963,
    "Neutron Flare": 964,
    "Halo Rockets": 965,
    "Optical Flare Grenade": 966,
    "Restoration Hit (Small)": 967,
    "Restoration Hit (Medium)": 968,
    "Restoration Hit (Large)": 969,
    "Heal (Small)": 970,
    "Heal (Medium)": 971,
    "Heal (Large)": 972,
    "Mind Control Hit (Small)": 973,
    "Mind Control Hit (Medium)": 974,
    "Mind Control Hit (Large)": 975,
    "Optical Flare Hit (Small)": 976,
    "Optical Flare Hit (Medium)": 977,
    "Optical Flare Hit (Large)": 978,
    "Feedback (Small)": 979,
    "Feedback (Medium)": 980,
    "Feedback Hit (Large)": 981,
    "Maelstrom Overlay (Small)": 982,
    "Maelstrom Overlay (Medium)": 983,
    "Maelstrom Overlay (Large)": 984,
    "Subterranean Spines Hit": 985,
    "Acid Spores (1) Overlay (Small)": 986,
    "Acid Spores (2-3) Overlay (Small)": 987,
    "Acid Spores (4-5) Overlay (Small)": 988,
    "Acid Spores (6-9) Overlay (Small)": 989,
    "Acid Spores (1) Overlay (Medium)": 990,
    "Acid Spores (2-3) Overlay (Medium)": 991,
    "Acid Spores (4-5) Overlay (Medium)": 992,
    "Acid Spores (6-9) Overlay (Medium)": 993,
    "Acid Spores (1) Overlay (Large)": 994,
    "Acid Spores (2-3) Overlay (Large)": 995,
    "Acid Spores (4-5) Overlay (Large)": 996,
    "Acid Spores (6-9) Overlay (Large)": 997,
    "Maelstrom Hit": 998,
}

DefaultImage: TypeAlias = Literal[
    "Scourge",
    "Scourge Shadow",
    "Scourge Birth",
    "Scourge Death",
    "Scourge Explosion",
    "Broodling",
    "Broodling Shadow",
    "Broodling Remnants",
    "Infested Terran",
    "Infested Terran Shadow",
    "Infested Terran Explosion",
    "Guardian Cocoon",
    "Guardian Cocoon Shadow",
    "Defiler",
    "Defiler Shadow",
    "Defiler Birth",
    "Defiler Remnants",
    "Drone",
    "Drone Shadow",
    "Drone Birth",
    "Drone Remnants",
    "Egg",
    "Egg Shadow",
    "Egg Spawn",
    "Egg Remnants",
    "Guardian",
    "Guardian Shadow",
    "Guardian Birth",
    "Guardian Death",
    "Hydralisk",
    "Hydralisk Shadow",
    "Hydralisk Birth",
    "Hydralisk Remnants",
    "Infested Kerrigan",
    "Infested Kerrigan Shadow",
    "Needle Spines",
    "Larva",
    "Larva Remnants",
    "Mutalisk",
    "Mutalisk Shadow",
    "Mutalisk Birth",
    "Mutalisk Death",
    "Overlord",
    "Overlord Shadow",
    "Overlord Birth",
    "Overlord Death",
    "Queen",
    "Queen Shadow",
    "Queen Death",
    "Queen Birth",
    "Ultralisk",
    "Ultralisk Shadow",
    "Ultralisk Birth",
    "Ultralisk Remnants",
    "Zergling",
    "Zergling Shadow",
    "Zergling Birth",
    "Zergling Remnants",
    "Zerg Air Death Explosion (Large)",
    "Zerg Air Death Explosion (Small)",
    "Zerg Building Explosion",
    "Cerebrate",
    "Cerebrate Shadow",
    "Infested Command Center",
    "Spawning Pool",
    "Spawning Pool Shadow",
    "Evolution Chamber",
    "Evolution Chamber Shadow",
    "Creep Colony",
    "Creep Colony Shadow",
    "Hatchery",
    "Hatchery Shadow",
    "Hive",
    "Hive Shadow",
    "Lair",
    "Lair Shadow",
    "Sunken Colony",
    "Sunken Colony Shadow",
    "Mature Chrysalis",
    "Mature Chrysalis Shadow",
    "Greater Spire",
    "Greater Spire Shadow",
    "Defiler Mound",
    "Defiler Mound Shadow",
    "Queen's Nest",
    "Queen's Nest Shadow",
    "Nydus Canal",
    "Nydus Canal Shadow",
    "Overmind With Shell",
    "Overmind Remnants",
    "Overmind Without Shell",
    "Ultralisk Cavern",
    "Ultralisk Cavern Shadow",
    "Extractor",
    "Extractor Shadow",
    "Hydralisk Den",
    "Hydralisk Den Shadow",
    "Spire",
    "Spire Shadow",
    "Spore Colony",
    "Spore Colony Shadow",
    "Infested Command Center Overlay",
    "Zerg Construction (Large)",
    "Zerg Building Morph",
    "Zerg Construction (Medium)",
    "Zerg Construction (Small)",
    "Zerg Building Construction Shadow",
    "Zerg Building Spawn (Small)",
    "Zerg Building Spawn (Medium)",
    "Zerg Building Spawn (Large)",
    "Zerg Building Rubble (Small)",
    "Zerg Building Rubble (Large)",
    "Carrier",
    "Carrier Shadow",
    "Carrier Engines",
    "Carrier Warp Flash",
    "Interceptor",
    "Interceptor Shadow",
    "Shuttle",
    "Shuttle Shadow",
    "Shuttle Engines",
    "Shuttle Warp Flash",
    "Dragoon",
    "Dragoon Shadow",
    "Dragoon Remnants",
    "Dragoon Warp Flash",
    "High Templar",
    "High Templar Shadow",
    "High Templar Warp Flash",
    "Dark Templar (Hero)",
    "Arbiter",
    "Arbiter Shadow",
    "Arbiter Engines",
    "Arbiter Warp Flash",
    "Archon Energy",
    "Archon Being",
    "Archon Swirl",
    "Probe",
    "Probe Shadow",
    "Probe Warp Flash",
    "Scout",
    "Scout Shadow",
    "Scout Engines",
    "Scout Warp Flash",
    "Reaver",
    "Reaver Shadow",
    "Reaver Warp Flash",
    "Scarab",
    "Observer",
    "Observer Shadow",
    "Observer Warp Flash",
    "Zealot",
    "Zealot Shadow",
    "Zealot Death",
    "Zealot Warp Flash",
    "Templar Archives",
    "Templar Archives Warp Flash",
    "Templar Archives Shadow",
    "Assimilator",
    "Assimilator Warp Flash",
    "Assimilator Shadow",
    "Observatory",
    "Observatory Warp Flash",
    "Observatory Shadow",
    "Citadel of Adun",
    "Citadel of Adun Warp Flash",
    "Citadel of Adun Shadow",
    "Forge",
    "Forge Overlay",
    "Forge Warp Flash",
    "Forge Shadow",
    "Gateway",
    "Gateway Warp Flash",
    "Gateway Shadow",
    "Cybernetics Core",
    "Cybernetics Core Warp Flash",
    "Cybernetics Core Overlay",
    "Cybernetics Core Shadow",
    "Khaydarin Crystal Formation",
    "Nexus",
    "Nexus Warp Flash",
    "Nexus Overlay",
    "Nexus Shadow",
    "Photon Cannon",
    "Photon Cannon Shadow",
    "Photon Cannon Warp Flash",
    "Arbiter Tribunal",
    "Arbiter Tribunal Warp Flash",
    "Arbiter Tribunal Shadow",
    "Pylon",
    "Pylon Warp Flash",
    "Pylon Shadow",
    "Robotics Facility",
    "Robotics Facility Warp Flash",
    "Robotics Facility Shadow",
    "Shield Battery",
    "Shield Battery Overlay",
    "Shileld Battery Warp Flash",
    "Shield Battery Shadow",
    "Stargate",
    "Stargate Overlay",
    "Stargate Warp Flash",
    "Stargate Shadow",
    "Stasis Cell/Prison",
    "Robotics Support Bay",
    "Robotics Support Bay Warp Flash",
    "Robotics Support Bay Shadow",
    "Protoss Temple",
    "Fleet Beacon",
    "Fleet Beacon Warp Flash",
    "Warp Texture",
    "Warp Anchor",
    "Fleet Beacon Shadow",
    "Explosion1 (Small)",
    "Explosion1 (Medium)",
    "Explosion (Large)",
    "Protoss Building Rubble (Small)",
    "Protoss Building Rubble (Large)",
    "Battlecruiser",
    "Battlecruiser Shadow",
    "Battlecruiser Engines",
    "Civilian",
    "Civilian Shadow",
    "Dropship",
    "Dropship Shadow",
    "Dropship Engines",
    "Firebat",
    "Firebat Shadow",
    "Ghost",
    "Ghost Shadow",
    "Ghost Remnants",
    "Ghost Death",
    "Nuke Beam",
    "Nuke Target Dot",
    "Goliath Base",
    "Goliath Turret",
    "Goliath Shadow",
    "Sarah Kerrigan",
    "Sarah Kerrigan Shadow",
    "Marine",
    "Marine Shadow",
    "Marine Remnants",
    "Marine Death",
    "Wraith",
    "Wraith Shadow",
    "Wraith Engines",
    "Scanner Sweep",
    "SCV",
    "SCV Shadow",
    "SCV Glow",
    "Siege Tank (Tank) Base",
    "Siege Tank (Tank) Turret",
    "Siege Tank (Tank) Base Shadow",
    "Siege Tank (Siege) Base",
    "Siege Tank (Siege) Turret",
    "Siege Tank (Siege) Base Shadow",
    "Vulture",
    "Vulture Shadow",
    "Spider Mine",
    "Spider Mine Shadow",
    "Science Vessel (Base)",
    "Science Vessel (Turret)",
    "Science Vessel Shadow",
    "Terran Academy",
    "Academy Overlay",
    "Academy Shadow",
    "Barracks",
    "Barracks Shadow",
    "Armory",
    "Armory Overlay",
    "Armory Shadow",
    "Comsat Station",
    "Comsat Station Connector",
    "Comsat Station Overlay",
    "Comsat Station Shadow",
    "Command Center",
    "Command Center Overlay",
    "Command Center Shadow",
    "Supply Depot",
    "Supply Depot Overlay",
    "Supply Depot Shadow",
    "Control Tower",
    "Control Tower Connector",
    "Control Tower Overlay",
    "Control Tower Shadow",
    "Factory",
    "Factory Overlay",
    "Factory Shadow",
    "Covert Ops",
    "Covert Ops Connector",
    "Covert Ops Overlay",
    "Covert Ops Shadow",
    "Ion Cannon",
    "Machine Shop",
    "Machine Shop Connector",
    "Machine Shop Shadow",
    "Missile Turret (Base)",
    "Missile Turret (Turret)",
    "Missile Turret (Base) Shadow",
    "Crashed Batlecruiser",
    "Crashed Battlecruiser Shadow",
    "Physics Lab",
    "Physics Lab Connector",
    "Physics Lab Shadow",
    "Bunker",
    "Bunker Shadow",
    "Bunker Overlay",
    "Refinery",
    "Refinery Shadow",
    "Science Facility",
    "Science Facility Overlay",
    "Science Facility Shadow",
    "Nuclear Silo",
    "Nuclear Silo Connector",
    "Nuclear Silo Overlay",
    "Nuclear Silo Shadow",
    "Nuclear Missile",
    "Nuclear Missile Shadow",
    "Nuke Hit",
    "Starport",
    "Starport Overlay",
    "Starport Shadow",
    "Engineering Bay",
    "Engineering Bay Overlay",
    "Engineering Bay Shadow",
    "Terran Construction (Large)",
    "Terran Construction (Large) Shadow",
    "Terran Construction (Medium)",
    "Terran Construction (Medium) Shadow",
    "Addon Construction",
    "Terran Construction (Small)",
    "Terran Construction (Small) Shadow",
    "Explosion2 (Small)",
    "Explosion2 (Medium)",
    "Building Explosion (Large)",
    "Terran Building Rubble (Small)",
    "Terran Building Rubble (Large)",
    "Dark Swarm",
    "Ragnasaur (Ash)",
    "Ragnasaur (Ash) Shadow",
    "Rhynadon (Badlands)",
    "Rhynadon (Badlands) Shadow",
    "Bengalaas (Jungle)",
    "Bengalaas (Jungle) Shadow",
    "Vespene Geyser",
    "Vespene Geyser2",
    "Vespene Geyser Shadow",
    "Mineral Field Type1",
    "Mineral Field Type1 Shadow",
    "Mineral Field Type2",
    "Mineral Field Type2 Shadow",
    "Mineral Field Type3",
    "Mineral Field Type3 Shadow",
    "Independent Starport (Unused)",
    "Zerg Beacon",
    "Zerg Beacon Overlay",
    "Terran Beacon",
    "Terran Beacon Overlay",
    "Protoss Beacon",
    "Protoss Beacon Overlay",
    "Magna Pulse (Unused)",
    "Lockdown Field (Small)",
    "Lockdown Field (Medium)",
    "Lockdown Field (Large)",
    "Stasis Field Hit",
    "Stasis Field (Small)",
    "Stasis Field (Medium)",
    "Stasis Field (Large)",
    "Recharge Shields (Small)",
    "Recharge Shields (Medium)",
    "Recharge Shields (Large)",
    "Defensive Matrix Front (Small)",
    "Defensive Matrix Front (Medium)",
    "Defensive Matrix Front (Large)",
    "Defensive Matrix Back (Small)",
    "Defensive Matrix Back (Medium)",
    "Defensive Matrix Back (Large)",
    "Defensive Matrix Hit (Small)",
    "Defensive Matrix Hit (Medium)",
    "Defensive Matrix Hit (Large)",
    "Irradiate (Small)",
    "Irradiate (Medium)",
    "Irradiate (Large)",
    "Ensnare Cloud",
    "Ensnare Overlay (Small)",
    "Ensnare Overlay (Medium)",
    "Ensnare Overlay (Large)",
    "Plague Cloud",
    "Plague Overlay (Small)",
    "Plague Overlay (Medium)",
    "Plague Overlay (Large)",
    "Recall Field",
    "Flag",
    "Young Chrysalis",
    "Psi Emitter",
    "Data Disc",
    "Khaydarin Crystal",
    "Mineral Chunk Type1",
    "Mineral Chunk Type2",
    "Protoss Gas Orb Type1",
    "Protoss Gas Orb Type2",
    "Zerg Gas Sac Type1",
    "Zerg Gas Sac Type2",
    "Terran Gas Tank Type1",
    "Terran Gas Tank Type2",
    "Mineral Chunk Shadow",
    "Protoss Gas Orb Shadow",
    "Zerg Gas Sac Shadow",
    "Terran Gas Tank Shadow",
    "Data Disk Shadow (Ground)",
    "Data Disk Shadow (Carried)",
    "Flag Shadow (Ground)",
    "Flag Shadow (Carried)",
    "Crystal Shadow (Ground)",
    "Crystal Shadow (Carried)",
    "Young Chrysalis Shadow (Ground)",
    "Young Chrysalis Shadow (Carried)",
    "Psi Emitter Shadow (Ground)",
    "Psi Emitter Shadow (Carried)",
    "Acid Spray (Unused)",
    "Plasma Drip (Unused)",
    "FlameThrower",
    "Longbolt/Gemini Missiles Trail",
    "Burrowing Dust",
    "Shield Overlay",
    "Small Explosion (Unused)",
    "Double Explosion",
    "Phase Disruptor Hit",
    "Nuclear Missile Death",
    "Spider Mine Death",
    "Vespene Geyser Smoke1",
    "Vespene Geyser Smoke2",
    "Vespene Geyser Smoke3",
    "Vespene Geyser Smoke4",
    "Vespene Geyser Smoke5",
    "Vespene Geyser Smoke1 Overlay",
    "Vespene Geyser Smoke2 Overlay",
    "Vespene Geyser Smoke3 Overlay",
    "Vespene Geyser Smoke4 Overlay",
    "Vespene Geyser Smoke5 Overlay",
    "Fragmentation Grenade Hit",
    "Grenade Shot Smoke",
    "Anti-Matter Missile Hit",
    "Scarab/Anti-Matter Missile Overlay",
    "Scarab Hit",
    "Cursor Marker",
    "Battlecruiser Attack Overlay",
    "Burst Lasers Hit",
    "Burst Lasers Overlay (Unused)",
    "High Templar Glow",
    "Flames1 Type1 (Small)",
    "Flames1 Type2 (Small)",
    "Flames1 Type3 (Small)",
    "Flames2 Type3 (Small)",
    "Flames3 Type3 (Small)",
    "Flames4 Type3 (Small)",
    "Flames5 Type3 (Small)",
    "Flames6 Type3 (Small)",
    "Bleeding Variant1 Type1 (Small)",
    "Bleeding Variant1 Type2 (Small)",
    "Bleeding Variant1 Type3 (Small)",
    "Bleeding Variant1 Type4 (Small)",
    "Bleeding Variant2 Type1 (Small)",
    "Bleeding Variant2 Type2 (Small)",
    "Bleeding Variant2 Type3 (Small)",
    "Bleeding Variant2 Type4 (Small)",
    "Flames2 Type1 (Small)",
    "Flames2 Type2 (Small)",
    "Flames7 Type3 (Small)",
    "Flames3 Type1 (Small)",
    "Flames3 Type2 (Small)",
    "Flames8 Type3 (Small)",
    "Flames1 Type1 (Large)",
    "Flames1 Type2 (Large)",
    "Flames1 Type3 (Large)",
    "Flames2 Type3 (Large)",
    "Flames3 Type3 (Large)",
    "Flames4 Type3 (Large)",
    "Flames5 Type3 (Large)",
    "Flames6 Type3 (Large)",
    "Bleeding Variant1 Type1 (Large)",
    "Bleeding Variant1 Type2 (Large)",
    "Bleeding Variant1 Type3 (Large)",
    "Bleeding Variant1 Type4 (Large)",
    "Bleeding Variant2 Type1 (Large)",
    "Bleeding Variant2 Type3 (Large)",
    "Bleeding Variant3 Type3 (Large)",
    "Bleeding Variant2 Type4 (Large)",
    "Flames2 Type1 (Large)",
    "Flames2 Type2 (Large)",
    "Flames7 Type3 (Large)",
    "Flames3 Type1 (Large)",
    "Flames3 Type2 (Large)",
    "Flames8 Type3 (Large)",
    "Building Landing Dust Type1",
    "Building Landing Dust Type2",
    "Building Landing Dust Type3",
    "Building Landing Dust Type4",
    "Building Landing Dust Type5",
    "Building Lifting Dust Type1",
    "Building Lifting Dust Type2",
    "Building Lifting Dust Type3",
    "Building Lifting Dust Type4",
    "White Circle",
    "Needle Spine Hit",
    "Plasma Drip Hit (Unused)",
    "Sunken Colony Tentacle",
    "Venom (Unused Zerg Weapon)",
    "Venom Hit (Unused)",
    "Acid Spore",
    "Acid Spore Hit",
    "Glave Wurm",
    "Glave Wurm/Seeker Spores Hit",
    "Glave Wurm Trail",
    "Seeker Spores Overlay",
    "Seeker Spores",
    "Queen Spell Holder",
    "Consume",
    "Guardian Attack Overlay",
    "Dual Photon Blasters Hit",
    "Particle Beam Hit",
    "Anti-Matter Missile",
    "Pulse Cannon",
    "Phase Disruptor",
    "STA/STS Photon Cannon Overlay",
    "Psionic Storm",
    "Fusion Cutter Hit",
    "Gauss Rifle Hit",
    "Gemini Missiles",
    "Lockdown/LongBolt/Hellfire Missile",
    "Gemini Missiles Explosion",
    "C-10 Canister Rifle Hit",
    "Fragmentation Grenade",
    "Arclite Shock Cannon Hit",
    "ATS/ATA Laser Battery",
    "Burst Lasers",
    "Siege Tank(Tank) Turret Attack Overlay",
    "Siege Tank(Siege) Turret Attack Overlay",
    "Science Vessel Overlay (Part1)",
    "Science Vessel Overlay (Part2)",
    "Science Vessel Overlay (Part3)",
    "Yamato Gun",
    "Yamato Gun Trail",
    "Yamato Gun Overlay",
    "Yamato Gun Hit",
    "Hallucination Hit",
    "Scanner Sweep Hit",
    "Archon Birth (Unused)",
    "Psionic Shockwave Hit",
    "Archon Beam",
    "Psionic Storm Part1",
    "Psionic Storm Part2",
    "Psionic Storm Part3",
    "Psionic Storm Part4",
    "EMP Shockwave Missile",
    "EMP Shockwave Hit (Part1)",
    "EMP Shockwave Hit (Part2)",
    "Hallucination Death1",
    "Hallucination Death2",
    "Hallucination Death3",
    "Circle Marker1",
    "Selection Circle (22pixels)",
    "Selection Circle (32pixels)",
    "Selection Circle (48pixels)",
    "Selection Circle (62pixels)",
    "Selection Circle (72pixels)",
    "Selection Circle (94pixels)",
    "Selection Circle (110pixels)",
    "Selection Circle (122pixels)",
    "Selection Circle (146pixels)",
    "Selection Circle (224pixels)",
    "Selection Circle Dashed (22pixels)",
    "Selection Circle Dashed (32pixels)",
    "Selection Circle Dashed (48pixels)",
    "Selection Circle Dashed (62pixels)",
    "Selection Circle Dashed (72pixels)",
    "Selection Circle Dashed (94pixels)",
    "Selection Circle Dashed (110pixels)",
    "Selection Circle Dashed (122pixels)",
    "Selection Circle Dashed (146pixels)",
    "Selection Circle Dashed (224pixels)",
    "Circle Marker2",
    "Map Revealer",
    "Circle Marker3",
    "Psi Field1 (Right Upper)",
    "Psi Field1 (Right Lower)",
    "Psi Field2 (Right Upper)",
    "Psi Field2 (Right Lower)",
    "Start Location",
    "2/38 Ash",
    "2/38 Ash Shadow",
    "2/39 Ash",
    "2/39 Ash Shadow",
    "2/41 Ash",
    "2/41 Ash Shadow",
    "2/40 Ash",
    "2/40 Ash Shadow",
    "2/42 Ash",
    "2/42 Ash Shadow",
    "2/43 Ash",
    "2/44 Ash",
    "2/1 Ash",
    "2/4 Ash",
    "2/5 Ash",
    "2/30 Ash",
    "2/28 Ash",
    "2/29 Ash",
    "4/1 Ash",
    "4/2 Ash",
    "4/3 Ash",
    "4/56 Jungle",
    "4/56 Jungle Shadow",
    "4/57 Jungle",
    "4/57 Jungle Shadow",
    "4/58 Jungle",
    "4/58 Jungle Shadow",
    "4/59 Jungle",
    "4/59 Jungle Shadow",
    "9/5 Jungle",
    "9/5 Jungle Shadow",
    "9/6 Jungle",
    "9/6 Jungle Shadow",
    "9/7 Jungle",
    "9/7 Jungle Shadow",
    "4/51 Jungle",
    "4/51 Jungle Shadow",
    "4/52 Jungle",
    "4/52 Jungle Shadow",
    "4/54 Jungle",
    "4/54 Jungle Shadow",
    "4/53 Jungle",
    "4/53 Jungle Shadow",
    "9/1 Jungle",
    "9/1 Jungle Shadow",
    "9/2 Jungle",
    "9/2 Jungle Shadow",
    "9/3 Jungle",
    "9/3 Jungle Shadow",
    "9/4 Jungle",
    "9/4 Jungle Shadow",
    "4/12 Jungle",
    "4/13 Jungle",
    "4/1 Jungle",
    "4/3 Jungle",
    "4/2 Jungle",
    "4/5 Jungle",
    "4/4 Jungle",
    "4/9 Jungle",
    "4/10 Jungle",
    "5/5 Jungle",
    "5/7 Jungle",
    "5/6 Jungle",
    "5/9 Jungle",
    "5/8 Jungle",
    "4/6 Jungle",
    "4/7 Jungle",
    "4/17 Jungle",
    "13/4 Jungle",
    "11/5 Jungle",
    "11/6 Jungle",
    "11/7 Jungle",
    "11/8 Jungle",
    "11/10 Jungle",
    "11/11 Jungle",
    "11/12 Jungle",
    "7/4 Platform",
    "7/4 Platform Shadow",
    "7/5 Platform",
    "7/5 Platform Shadow",
    "7/6 Platform",
    "7/6 Platform Shadow",
    "7/1 Platform",
    "7/1 Platform Shadow",
    "7/2 Platform",
    "7/2 Platform Shadow",
    "7/3 Platform",
    "7/3 Platform Shadow",
    "7/9 Platform",
    "7/10 Platform",
    "7/8 Platform",
    "7/7 Platform",
    "7/26 Platform",
    "7/24 Platform",
    "7/28 Platform",
    "7/27 Platform",
    "7/25 Platform",
    "7/29 Platform",
    "7/30 Platform",
    "7/31 Platform",
    "12/1 Platform",
    "9/27 Platform",
    "5/54 Badlands",
    "5/54 Badlands Shadow",
    "5/55 Badlands",
    "5/55 Badlands Shadow",
    "5/56 Badlands",
    "5/56 Badlands Shadow",
    "5/57 Badlands",
    "5/57 Badlands Shadow",
    "6/16 Badlands",
    "6/17 Badlands",
    "6/20 Badlands",
    "6/21 Badlands",
    "5/10 Badlands",
    "5/50 Badlands",
    "5/50 Badlands Shadow",
    "5/52 Badlands",
    "5/52 Badlands Shadow",
    "5/53 Badlands",
    "5/53 Badlands Shadow",
    "5/51 Badlands",
    "5/51 Badlands Shadow",
    "6/3 Badlands",
    "11/3 Badlands",
    "11/8 Badlands",
    "11/6 Badlands",
    "11/7 Badlands",
    "11/9 Badlands",
    "11/10 Badlands",
    "11/11 Badlands",
    "11/12 Badlands",
    "11/13 Badlands",
    "11/14 Badlands",
    "1/13 Badlands",
    "1/9 Badlands",
    "1/11 Badlands",
    "1/14 Badlands",
    "1/10 Badlands",
    "1/12 Badlands",
    "1/15 Badlands",
    "1/7 Badlands",
    "1/5 Badlands",
    "1/16 Badlands",
    "1/8 Badlands",
    "1/6 Badlands",
    "Floor Gun Trap",
    "Floor Missile Trap",
    "Floor Missile Trap Turret",
    "Wall Missile Trap",
    "Wall Missile Trap2",
    "Wall Flame Trap",
    "Wall Flame Trap2",
    "Left Upper Level Door",
    "Right Upper Level Door",
    "4/15 Installation1",
    "4/15 Installation2",
    "3/9 Installation",
    "3/10 Installation",
    "3/11 Installation",
    "3/12 Installation",
    "Substructure Left Door",
    "Substructure Right Door",
    "3/1 Installation",
    "3/2 Installation",
    "Substructure Opening Hole",
    "7/21 Twilight",
    "Unknown Twilight",
    "7/13 Twilight",
    "7/14 Twilight",
    "7/16 Twilight",
    "7/15 Twilight",
    "7/19 Twilight",
    "7/20 Twilight",
    "7/17 Twilight",
    "6/1 Twilight",
    "6/2 Twilight",
    "6/3 Twilight",
    "6/4 Twilight",
    "6/5 Twilight",
    "8/3 Twilight1",
    "8/3 Twilight2",
    "9/29 Ice",
    "9/29 Ice Shadow",
    "9/28 Ice",
    "9/28 Ice Shadow",
    "12/38 Ice",
    "12/38 Ice Shadow",
    "12/37 Ice",
    "12/37 Ice Shadow",
    "12/33 Ice1",
    "12/33 Ice1 Shadow",
    "9/21 Ice",
    "9/21 Ice Shadow",
    "9/15 Ice",
    "9/15 Ice Shadow",
    "9/16 Ice",
    "9/16 Ice Shadow",
    "Unknown787",
    "Unknown788",
    "12/9 Ice1",
    "12/10 Ice1",
    "9/24 Ice",
    "9/24 Ice Shadow",
    "9/23 Ice",
    "9/23 Ice Shadow",
    "Unknown795",
    "Unknown Ice Shadow",
    "12/7 Ice",
    "12/7 Ice Shadow",
    "12/8 Ice",
    "12/8 Ice Shadow",
    "12/9 Ice2",
    "12/9 Ice2 Shadow",
    "12/10 Ice2",
    "12/10 Ice2 Shadow",
    "12/40 Ice",
    "12/40 Ice Shadow",
    "12/41 Ice",
    "12/41 Ice Shadow",
    "12/42 Ice",
    "12/42 Ice Shadow",
    "12/5 Ice",
    "12/5 Ice Shadow",
    "12/6 Ice",
    "12/6 Ice Shadow",
    "12/36 Ice",
    "12/36 Ice Shadow",
    "12/32 Ice",
    "12/32 Ice Shadow",
    "12/33 Ice2",
    "12/33 Ice2 Shadow",
    "12/34 Ice",
    "12/34 Ice Shadow",
    "12/24 Ice1",
    "12/24 Ice1 Shadow",
    "12/25 Ice1",
    "12/25 Ice1 Shadow",
    "12/30 Ice1",
    "12/30 Ice1 Shadow",
    "12/31 Ice",
    "12/31 Ice Shadow",
    "12/20 Ice",
    "12/30 Ice2",
    "12/30 Ice2 Shadow",
    "9/22 Ice",
    "9/22 Ice Shadow",
    "12/24 Ice2",
    "12/24 Ice2 Shadow",
    "12/25 Ice2",
    "12/25 Ice2 Shadow",
    "Unknown840",
    "4/1 Ice",
    "6/1 Ice",
    "5/6 Ice",
    "5/6 Ice Shadow",
    "5/7 Ice",
    "5/7 Ice Shadow",
    "5/8 Ice",
    "5/8 Ice Shadow",
    "5/9 Ice",
    "5/9 Ice Shadow",
    "10/10 Desert1",
    "10/12 Desert1",
    "10/12 Desert1 Shadow",
    "10/8 Desert1",
    "10/8 Desert1 Shadow",
    "10/9 Desert1",
    "10/9 Desert1 Shadow",
    "6/10 Desert",
    "6/10 Desert Shadow",
    "6/13 Desert1",
    "6/13 Desert1 Shadow",
    "Unknown Desert",
    "Unknown Desert Shadow",
    "10/12 Desert2",
    "10/12 Desert2 Shadow",
    "10/9 Desert2",
    "10/9 Desert2 Shadow",
    "10/10 Desert2",
    "10/10 Desert2 Shadow",
    "10/11 Desert",
    "10/11 Desert Shadow",
    "10/14 Desert",
    "10/14 Desert Shadow",
    "10/41 Desert",
    "10/41 Desert Shadow",
    "10/39 Desert",
    "1/39 Desert Shadow",
    "10/8 Desert2",
    "10/8 Desert2 Shadow",
    "10/6 Desert",
    "10/7 Desert",
    "10/7 Desert Shadow",
    "4/6 Desert",
    "4/6 Desert Shadow",
    "4/11 Desert",
    "4/11 Desert Shadow",
    "4/10 Desert",
    "4/10 Desert Shadow",
    "4/9 Desert",
    "4/7 Desert",
    "4/7 Desert Shadow",
    "4/12 Desert",
    "4/12 Desert Shadow",
    "4/8 Desert",
    "4/13 Desert",
    "4/13 Desert Shadow",
    "4/17 Desert",
    "4/15 Desert1",
    "4/15 Desert1 Shadow",
    "10/23 Desert",
    "10/23 Desert Shadow",
    "10/5 Desert",
    "10/5 Desert Shadow",
    "6/13 Desert2",
    "6/13 Desert2 Shadow",
    "6/20 Desert",
    "4/15 Desert2",
    "4/15 Desert2 Shadow",
    "8/23 Desert",
    "8/23 Desert Shadow",
    "12/1 Desert Overlay",
    "11/3 Desert",
    "Unknown913",
    "Lurker Egg",
    "Devourer",
    "Devourer Shadow",
    "Devourer Birth",
    "Devourer Death",
    "Lurker Birth",
    "Lurker Remnants",
    "Lurker",
    "Lurker Shadow",
    "Overmind Cocoon",
    "Overmind Cocoon Shadow",
    "Dark Archon Energy",
    "Dark Archon Being",
    "Dark Archon Swirl",
    "Dark Archon Death",
    "Corsair",
    "Corsair Shadow",
    "Corsair Engines",
    "Neutron Flare Overlay (Unused)",
    "Dark Templar (Unit)",
    "Warp Gate",
    "Warp Gate Shadow",
    "Warp Gate Overlay",
    "Xel'Naga Temple",
    "Xel'Naga Temple Shadow",
    "Valkyrie",
    "Valkyrie Shadow",
    "Valkyrie Engines",
    "Valkyrie Engines2 (Unused)",
    "Valkyrie Afterburners (Unused)",
    "Medic",
    "Medic Shadow",
    "Medic Remnants",
    "Psi Disrupter",
    "Psi Disrupter Shadow",
    "Power Generator",
    "Power Generator Shadow",
    "Disruption Web",
    "Scantid (Desert)",
    "Scantid (Desert) Shadow",
    "Kakaru (Twilight)",
    "Kakaru (Twilight) Shadow",
    "Ursadon (Ice)",
    "Ursadon (Ice) Shadow",
    "Uraj",
    "Khalis",
    "Halo Rockets Trail",
    "Subterranean Spines",
    "Corrosive Acid Shot",
    "Corrosive Acid Hit",
    "Neutron Flare",
    "Halo Rockets",
    "Optical Flare Grenade",
    "Restoration Hit (Small)",
    "Restoration Hit (Medium)",
    "Restoration Hit (Large)",
    "Heal (Small)",
    "Heal (Medium)",
    "Heal (Large)",
    "Mind Control Hit (Small)",
    "Mind Control Hit (Medium)",
    "Mind Control Hit (Large)",
    "Optical Flare Hit (Small)",
    "Optical Flare Hit (Medium)",
    "Optical Flare Hit (Large)",
    "Feedback (Small)",
    "Feedback (Medium)",
    "Feedback Hit (Large)",
    "Maelstrom Overlay (Small)",
    "Maelstrom Overlay (Medium)",
    "Maelstrom Overlay (Large)",
    "Subterranean Spines Hit",
    "Acid Spores (1) Overlay (Small)",
    "Acid Spores (2-3) Overlay (Small)",
    "Acid Spores (4-5) Overlay (Small)",
    "Acid Spores (6-9) Overlay (Small)",
    "Acid Spores (1) Overlay (Medium)",
    "Acid Spores (2-3) Overlay (Medium)",
    "Acid Spores (4-5) Overlay (Medium)",
    "Acid Spores (6-9) Overlay (Medium)",
    "Acid Spores (1) Overlay (Large)",
    "Acid Spores (2-3) Overlay (Large)",
    "Acid Spores (4-5) Overlay (Large)",
    "Acid Spores (6-9) Overlay (Large)",
    "Maelstrom Hit",
]



# Copyright 2014 by trgk.
# All rights reserved.
# This file is part of EUD python library (eudplib),
# and is released under "MIT License Agreement". Please see the LICENSE
# file that should have been included as part of this package.

import os

from ..bindings._rust import mpqapi
from ..core.mapdata import chktok, mapdata
from ..localize import _
from ..utils import EPError, ep_eprint
from .mpqadd import update_filelist_by_listfile

_load_map_path = None


def LoadMap(fname: str) -> None:  # noqa: N802
    """Load basemap from fname

    :param fname: Path for basemap.
    """
    global _load_map_path

    print(_("Loading map {}").format(fname))
    if not os.path.isfile(fname):
        raise FileNotFoundError(_("input path is not a map file"))
    try:
        with open(fname, "rb") as file:
            rawfile = file.read()
    except FileNotFoundError:
        ep_eprint(_("input map does not exist"))
        raise
    except PermissionError:
        ep_eprint(
            _("You lacks permission to get access rights for input map"),
            _("Try to turn off antivirus or StarCraft"),
            sep="\n",
        )
        raise
    try:
        mpqr = mpqapi.MPQ.open(fname)
    except Exception as e:
        raise EPError(_("Fail to open input map")) from e

    try:
        b = mpqr.extract_file("staredit\\scenario.chk")
    except Exception as e:
        raise EPError(_("Fail to extract scenario.chk, maybe invalid scx")) from e
    if len(b) <= 1200:  # fake scenario.chk
        mpqr.set_file_locale(0x409)
        try:
            b = mpqr.extract_file("staredit\\scenario.chk")
        except Exception as e:
            raise EPError(
                _("Fail to extract scenario.chk, maybe invalid scx")
            ) from e
        mpqr.set_file_locale(0)
    chkt = chktok.CHK()
    chkt.loadchk(b)
    mapdata.init_map_data(chkt, rawfile)
    update_filelist_by_listfile(mpqr)
    del mpqr
    _load_map_path = fname



# Copyright 2014 by trgk.
# All rights reserved.
# This file is part of EUD python library (eudplib),
# and is released under "MIT License Agreement". Please see the LICENSE
# file that should have been included as part of this package.

import types
from typing import Generic, TypeAlias, TypeGuard, TypeVar, overload

from ..localize import _
from .eperror import EPError

T_co = TypeVar("T_co", covariant=True)


class ExprProxy(Generic[T_co]):
    """Class which can contain both ConstExpr and EUDVariable"""

    __slots__ = ("_value",)

    def __init__(self, initval: T_co) -> None:
        # Python __slots__ is just a sugar for auto-generated descriptors.
        # Calling descriptors is implemented within __setattr__ and __getattr__
        # (or __*attribute__, I haven't dug deep) of object. The most importantly,
        # we have overridden the default __setattr__ and as a result, were unable to
        # initialize the value using dot notation within the ctor. Since the value of
        # the slotted variable is not yet initialized, our __setattr__ causes access
        # to __getattr__ (an incorrect behaviour by itself!), and __getattr__ needs
        # the slotted variable itself, so - infinite recursion.
        #
        # So, to initialize the value correctly, we should call the descriptor method
        # explicitly. See: https://stackoverflow.com/a/63338642
        super().__setattr__("_value", initval)
        # self._value: T_co = initval

    @classmethod
    def cast(cls, _from):
        if type(_from) is cls:
            return _from
        try:
            return cls(_from=_from)
        except TypeError as e:
            raise TypeError(_("Type {} is not castable").format(cls.__name__), e)

    def getValue(self) -> T_co:  # noqa: N802
        return self._value

    def __str__(self):
        return f"{type(self).__name__}({self._value})"

    def __repr__(self):
        return self.__str__()

    def __len__(self):
        return len(self._value)

    def __hash__(self) -> int:
        return id(self)

    # Proxy arithmetic operators

    def Assign(self, other):  # noqa: N802
        from ..core import EUDVariable

        if not isinstance(self._value, EUDVariable):
            raise EPError(_("Can't assign {} to constant expression").format(other))
        if not (type(other) is int and other == 0):  # noqa: E721
            try:
                other = type(self).cast(other)
            except (AttributeError, TypeError):
                pass
        self._value.Assign(other)
        return self

    def __lshift__(self, other):
        return self.Assign(other)

    def __rlshift__(self, k):
        return k << self._value

    def __rshift__(self, k):
        return self._value >> k

    def __rrshift__(self, k):
        return k >> self._value

    def __add__(self, k):
        return self._value + k

    def __radd__(self, k):
        return k + self._value

    def __sub__(self, k):
        return self._value - k

    def __rsub__(self, k):
        return k - self._value

    def __mul__(self, k):
        return self._value * k

    def __rmul__(self, k):
        return k * self._value

    def __floordiv__(self, k):
        return self._value // k

    def __rfloordiv__(self, k):
        return k // self._value

    def __divmod__(self, k):
        return divmod(self._value, k)

    def __rdivmod__(self, k):
        return divmod(k, self._value)

    def __mod__(self, k):
        return self._value % k

    def __rmod__(self, k):
        return k % self._value

    def __and__(self, k):
        return self._value & k

    def __rand__(self, k):
        return k & self._value

    def __or__(self, k):
        return self._value | k

    def __ror__(self, k):
        return k | self._value

    def __xor__(self, k):
        return self._value ^ k

    def __rxor__(self, k):
        return k ^ self._value

    def __neg__(self):
        return -self._value

    def __invert__(self):
        return ~self._value

    def __bool__(self):
        return bool(self._value)

    # Proxy comparison operator

    def __eq__(self, k):
        return self._value == k

    def __ne__(self, k):
        return self._value != k

    def __le__(self, k):
        return self._value <= k

    def __lt__(self, k):
        return self._value < k

    def __ge__(self, k):
        return self._value >= k

    def __gt__(self, k):
        return self._value > k

    # TODO: add inplace operators

    # Proxy other methods

    def __getattr__(self, name):
        return getattr(super().__getattribute__("_value"), name)

    def __getitem__(self, name):
        return self._value[name]

    def __setitem__(self, name, newvalue):
        self._value[name] = newvalue

    def __iter__(self):
        try:
            return self._value.__iter__()
        except AttributeError as err:
            raise TypeError(err)

    def Evaluate(self):  # noqa: N802
        try:
            return self._value.Evaluate()
        except AttributeError:
            return self._value


T = TypeVar("T")


@overload
def unProxy(x: ExprProxy[T]) -> T:
    ...


@overload
def unProxy(x: T) -> T:
    ...


def unProxy(x):  # noqa: N802
    k = 0

    # Cyclic check without using list/set
    # x_cyclic_check = ((lambda x: x.getValue) ** (2**n))(x)
    # if there is a cycle, x will go though the cycle and meet with x_cyclic_check
    # since (2**n) diverges, this code can catch cycles up to any size.
    x_cyclic_check = x0 = x
    while isinstance(x, ExprProxy):
        x = x.getValue()
        if x is x_cyclic_check:
            # Reconstruct cyclic reference
            err = _("ExprProxy {} has cyclic references: ")
            x_list = []
            x_set = set()

            x = x0
            while x not in x_set:
                x_list.append(x)
                x_set.add(x)
                x = x.getValue()

            raise RecursionError(
                err.format(x_list[0]),
                x_list,
            )

        k += 1
        # only becomes true if k == 2**i for some integer i
        if k & (k - 1) == 0:
            x_cyclic_check = x

    return x


_ClassInfo: TypeAlias = type | types.UnionType | tuple["_ClassInfo", ...]


@overload
def isUnproxyInstance(x: object, cls: type) -> TypeGuard[type]:
    ...


@overload
def isUnproxyInstance(x: object, cls: types.UnionType) -> TypeGuard[types.UnionType]:
    ...


def isUnproxyInstance(x: object, cls: _ClassInfo) -> bool:  # noqa: N802
    if isinstance(x, cls):
        return True
    if isinstance(unProxy(x), cls):
        return True
    return False



import time

import helper
import profile_tool

start_time = time.time()
DoCoverageTest = False

if DoCoverageTest:
    import coverage

    cov = coverage.Coverage()
    cov.start()


helper.LoadMap("outputmap/basemap/basemap_wireframe.scx")
helper.EP_SetRValueStrictMode(True)

helper.InitialWireframe.wireframes("Terran Ghost", "Protoss Archon")
helper.InitialWireframe.wireframes(
    "Terran Siege Tank (Tank Mode)", "Terran Siege Tank (Tank Mode)"
)
helper.InitialWireframe.wireframes("Protoss Probe", "Terran Siege Tank (Tank Mode)")
helper.InitialWireframe.wireframes("Terran Goliath", "Terran Dropship")


@helper.EUDFunc
def foo():
    helper.InitialWireframe.wireframes("Devouring One", "Zerg Hive")
    helper.InitialWireframe.wireframes("Zerg Queen's Nest", "Protoss Photon Cannon")


@helper.TestInstance
def test_wireframe():
    foo()
    helper.InitialWireframe.wireframes("Protoss Scout", "Psi Emitter")
    helper.InitialWireframe.wireframes("Protoss Cybernetics Core", "Protoss Probe")
    helper.SetWireframes("Terran SCV", "Zerg Drone")


helper.CompressPayload(True)
helper.ShufflePayload(False)

# profile_tool.profile(f, "profile.json")
helper.SaveMap("outputmap/test_wireframe.scx", helper._testmain)
print("--- %s seconds ---" % (time.time() - start_time))

if DoCoverageTest:
    cov.stop()
    cov.html_report(include=["C:\\gitclones\\eudtrglib\\eudplib\\*"])



# Copyright 2024 by zzt (Defender).
# All rights reserved.
# This file is part of EUD python library (eudplib),
# and is released under "MIT License Agreement". Please see the LICENSE
# file that should have been included as part of this package.

# ruff: noqa: N815
from typing import ClassVar

from .. import utils as ut
from ..core.rawtrigger.constenc import EncodePlayer, PlayerDict, _Player
from ..core.rawtrigger.consttype import ConstType
from ..localize import _
from .offsetmap import ByteMember, DwordMember, EPDOffsetMap, MapStringMember


class TrgPlayer(EPDOffsetMap, _Player):
    """
    TrgPlayer is special in the sense that it is not directly related to game data;
    rather, it is intended to deal with various game state specific to players.
    e.g. the amount of gas a player has, can be accessed via TrgPlayer.
    """

    __slots__ = ()
    mineral: ClassVar[DwordMember] = DwordMember("array", 0x57F0F0)
    ore = mineral
    gas: ClassVar[DwordMember] = DwordMember("array", 0x57F120)
    cumulativeGas: ClassVar[DwordMember] = DwordMember("array", 0x57F150)
    cumulativeMineral: ClassVar[DwordMember] = DwordMember("array", 0x57F180)
    zergControlAvailable: ClassVar[DwordMember] = DwordMember("array", 0x582144)
    zergControlUsed: ClassVar[DwordMember] = DwordMember("array", 0x582174)
    zergControlMax: ClassVar[DwordMember] = DwordMember("array", 0x5821A4)
    terranSupplyAvailable: ClassVar[DwordMember] = DwordMember("array", 0x5821D4)
    terranSupplyUsed: ClassVar[DwordMember] = DwordMember("array", 0x582204)
    terranSupplyMax: ClassVar[DwordMember] = DwordMember("array", 0x582234)
    protossPsiAvailable: ClassVar[DwordMember] = DwordMember("array", 0x582264)
    protossPsiUsed: ClassVar[DwordMember] = DwordMember("array", 0x582294)
    protossPsiMax: ClassVar[DwordMember] = DwordMember("array", 0x5822C4)
    unitColor: ClassVar[ByteMember] = ByteMember("array", 0x581D76, stride=8)
    minimapColor: ClassVar[ByteMember] = ByteMember("array", 0x581DD6)
    remainingGamePause: ClassVar[ByteMember] = ByteMember(
        "array", 0x58D718
    )  # length=8
    missionObjectives: ClassVar[MapStringMember] = MapStringMember(
        "array", 0x58D6C4, stride=4
    )
    unitScore: ClassVar[DwordMember] = DwordMember("array", 0x581E44)
    "Score for units produced"
    buildingScore: ClassVar[DwordMember] = DwordMember("array", 0x582024)
    "Score for buildings produced"
    killScore: ClassVar[DwordMember] = DwordMember("array", 0x581F04)
    razingScore: ClassVar[DwordMember] = DwordMember("array", 0x582054)
    customScore: ClassVar[DwordMember] = DwordMember("array", 0x5822F4)
    # scoreUnitTotal = ArrayMember(0x581ED4)
    # numOfFactoriesRazed = ArrayMember(0x582114) Kills for "Factories"
    # numOfBuildingsRazed = ArrayMember(0x581FF4) Kills for "Buildings"
    # numOfUnitsKilled = ArrayMember(0x581EA4) Kills for "Any Unit"
    # humanID: ClassVar[DwordMember] = DwordMember("array", 0x57EE7C)
    # nationID: ClassVar[DwordMember] = DwordMember("array", 0x57EEC0)
    # networkStatus: ClassVar[DwordMember] = DwordMember("array", 0x57F0B8)
    # playerSlotType: ClassVar[ByteMember] = ByteMember("array", 0x57F1B4)
    # playerSlotRace: ClassVar[ByteMember] = ByteMember("array", 0x57F1C0)
    # sharedVision: ClassVar[DwordMember] = DwordMember("array", 0x57F1EC)
    # colorMapping: ClassVar[DwordMember] = DwordMember("array", 0x57F21C) length=8
    # singleplayerComputerRace: ClassVar[ByteMember] = ByteMember("array", 0x57F267) length=8  # noqa: E501
    # hasLeftGame = ArrayMember(0x581D62, Mk.BOOL) length=8
    # selectionCircleColor: ClassVar[ByteMember] = ByteMember("array", 0x581D6A)
    # ownedTotalUnitsScore = ArrayMember(0x581DE4)
    # ownedUnitsScore = ArrayMember(0x581E14)
    # numOfUnitsLost = ArrayMember(0x581E74) Deaths for "Any Unit"
    # scoreStructuresConstructedTotal = ArrayMember(0x581F34)
    # numOfBuildingsConstructed = ArrayMember(0x581F64)
    # numOfBuildingsOwned = ArrayMember(0x581F94)
    # numOfBuildingsLost = ArrayMember(0x581FC4) Deaths for "Buildings"
    # numOfFactoriesConstructed = ArrayMember(0x582084)
    # numOfFactoriesOwned = ArrayMember(0x5820B4)
    # numOfFactoriesLost = ArrayMember(0x5820E4) Deaths for "Factories"
    # larvaCount: ClassVar[ByteMember] = ByteMember("array", 0x585474)
    # force: ClassVar[ByteMember] = ByteMember("array", 0x58D5B0) length=8
    # allyStatus: ClassVar[ByteMember] = ByteMember("array", 0x58D634)
    # victoryStatus: ClassVar[ByteMember] = ByteMember("array", 0x58D700) length=8
    # startLocationPos = ArrayMember(0x58D720, Mk.POSITION) length=8
    # 0x58F442 Unknown Player Color Something length=8
    # triggerWaitTimer: ClassVar[DwordMember] = DwordMember("array", 0x650980) length=8  # noqa: E501
    # 0x6D0F3C Replay Header - Player Bytes: Read Only
    # 0x6D0FD1 Replay Header - Player Entries: Read Only
    # 0x6D1181 Replay Header - Player Colors: Read Only length=8
    # 0x6D11A1 Replay Header - Player Force Data: Read Only length=8

    @ut.classproperty
    def range(self):
        return (0, 11, 1)

    @classmethod
    def cast(cls, _from):
        if isinstance(_from, ConstType) and not isinstance(_from, cls):
            raise ut.EPError(_('"{}" is not a {}').format(_from, cls.__name__))
        return super().cast(_from)

    def __init__(self, initval) -> None:
        super().__init__(EncodePlayer(initval))


# fmt: off
P1, P2, P3, P4 = TrgPlayer(0), TrgPlayer(1), TrgPlayer(2), TrgPlayer(3)
P5, P6, P7, P8 = TrgPlayer(4), TrgPlayer(5), TrgPlayer(6), TrgPlayer(7)
P9, P10, P11, P12 = TrgPlayer(8), TrgPlayer(9), TrgPlayer(10), TrgPlayer(11)
Player1, Player2, Player3, Player4 = P1, P2, P3, P4
Player5, Player6, Player7, Player8 = P5, P6, P7, P8
Player9, Player10, Player11, Player12 = P9, P10, P11, P12
CurrentPlayer = TrgPlayer(13)
Foes, Allies, NeutralPlayers = TrgPlayer(14), TrgPlayer(15), TrgPlayer(16)
AllPlayers = TrgPlayer(17)
Force1, Force2, Force3, Force4 = TrgPlayer(18), TrgPlayer(19), TrgPlayer(20), TrgPlayer(21)  # noqa: E501
NonAlliedVictoryPlayers = TrgPlayer(26)
PlayerDict.update({
    P1: 0, P2: 1, P3: 2, P4: 3,
    P5: 4, P6: 5, P7: 6, P8: 7,
    P9: 8, P10: 9, P11: 10, P12: 11,
    CurrentPlayer: 13,
    Foes: 14, Allies: 15, NeutralPlayers: 16,
    AllPlayers: 17,
    Force1: 18, Force2: 19, Force3: 20, Force4: 21,
    NonAlliedVictoryPlayers: 26,
})
# fmt: on



import random
from helper import *


@TestInstance
def test_atan2():
    atanarray = EUDArray(360)
    for angle in EUDLoopRange(360):
        EP_SetRValueStrictMode(False)
        x, y = f_lengthdir(1000, angle)
        EP_SetRValueStrictMode(True)
        atanarray[angle] = f_atan2(y, x)

    # Value of atan2 may vary by 1 due to rounding error.
    # Here we check similarity.
    test_assert(
        "atan2 test", [atanarray[angle] - angle + 1 <= 2 for angle in range(360)]
    )

    atan256array = EUDArray(256)
    for angle in EUDLoopRange(256):
        EP_SetRValueStrictMode(False)
        x, y = f_lengthdir_256(1000, angle)
        EP_SetRValueStrictMode(True)
        atan256array[angle] = f_atan2_256(y, x)

    # Value of atan2 may vary by 1 due to rounding error.
    # Here we check similarity.
    test_assert(
        "atan2_256 test",
        [atan256array[angle] - angle + 1 <= 2 for angle in range(256)],
    )


@TestInstance
def test_specialized_div():
    x = EUDVariable()
    for i in range(0, 32):
        a = random.randint(1, 0xFFFFFFFF)
        b = 2 << i
        q, r = int(a / b), a - int(a / b) * b
        x << a
        test_equality(
            f"div_by_pow_of_2({a}, {b}) = {(q, r)}",
            f_div(x, b),
            [q, r],
        )


@TestInstance
def test_signed_div():
    for nth in range(4):
        for _ in range(4):
            a = random.randint(1, 0x7FFFFFFF)
            b = random.randint(1, a)
            if nth >= 2:
                a = -a
            if nth % 2 == 1:
                b = -b
            q, r = int(a / b), a - int(a / b) * b

            x = a if random.random() < 0.5 else EUDVariable(a)
            y = b if random.random() < 0.5 else EUDVariable(b)
            s = "EV{}".format(a) if IsEUDVariable(x) else str(a)
            t = "EV{}".format(b) if IsEUDVariable(y) else str(b)

            test_equality(
                f"div_towards_zero({s}, {t}) = {(q, r)}",
                f_div_towards_zero(x, y),
                [q, r],
            )

            EP_SetRValueStrictMode(False)
            test_equality(
                f"div_floor({s}, {t}) = {divmod(a, b)}",
                f_div_floor(x, y),
                divmod(a, b),
            )

            # https://github.com/rust-lang/rust/blob/91eb6f9acfcfde6832d547959ad2d95b1ac0b5dc/library/core/src/num/int_macros.rs#L2115-L2130
            r = r + abs(b) if r < 0 else r
            q = (a - r) // b
            test_equality(
                f"div_euclid({s}, {t}) = {(q, r)})", f_div_euclid(x, y), [q, r]
            )
            EP_SetRValueStrictMode(True)


test_operator("Square root", f_sqrt, lambda x: int(x**0.5))



from typing import Literal, TypeAlias

DefIconDict: dict[str, int] = {
    "Marine": 0,
    "Ghost": 1,
    "Vulture": 2,
    "Goliath": 3,
    "Blank (Goliath Turret)": 4,
    "Siege Tank (Tank Mode)": 5,
    "Blank (Tank Turret)": 6,
    "SCV": 7,
    "Wraith": 8,
    "Science Vessel": 9,
    "Gui Montag": 10,
    "Gui Montag (Firebat)": 10,
    "Dropship": 11,
    "Battlecruiser": 12,
    "Vulture Spider Mine": 13,
    "Nuclear Missile": 14,
    "Civilian": 15,
    "Sarah Kerrigan": 16,
    "Sarah Kerrigan (Ghost)": 16,
    "Alan Schezar": 17,
    "Alan Schezar (Goliath)": 17,
    "Blank (Alan Turret)": 18,
    "Jim Raynor (Vulture)": 19,
    "Jim Raynor (Marine)": 20,
    "Tom Kazansky": 21,
    "Tom Kazansky (Wraith)": 21,
    "Magellan": 22,
    "Magellan (Science Vessel)": 22,
    "Edmund Duke (Siege Tank)": 23,
    "Blank (Duke Turret)": 24,
    "Edmund Duke (Siege Mode)": 25,
    "Blank (Siege Duke Turret)": 26,
    "Blank (Arcturus Mengsk)": 27,
    "Hyperion": 28,
    "Hyperion (Battlecruiser)": 28,
    "Norad II (Battlecruiser)": 29,
    "Terran Siege Tank (Siege Mode)": 30,
    "Blank (Siege Tank Turret)": 31,
    "Firebat": 32,
    "Marine (Scanner Sweep)": 33,
    "Medic": 34,
    "Larva": 35,
    "Radioactive (Zerg Egg)": 36,
    "Zergling": 37,
    "Hydralisk": 38,
    "Ultralisk": 39,
    "Broodling": 40,
    "Drone": 41,
    "Overlord": 42,
    "Mutalisk": 43,
    "Guardian": 44,
    "Queen": 45,
    "Defiler": 46,
    "Scourge": 47,
    "Torrarsque": 48,
    "Torrarsque (Ultralisk)": 48,
    "Matriarch": 49,
    "Matriarch (Queen)": 49,
    "Infested Terran": 50,
    "Infested Kerrigan": 51,
    "Infested Kerrigan (Infested Terran)": 51,
    "Unclean One": 52,
    "Unclean One (Defiler)": 52,
    "Hunter Killer": 53,
    "Hunter Killer (Hydralisk)": 53,
    "Devouring One": 54,
    "Devouring One (Zergling)": 54,
    "Kukulza (Mutalisk)": 55,
    "Kukulza (Guardian)": 56,
    "Yggdrasill": 57,
    "Yggdrasill (Overlord)": 57,
    "Valkyrie": 58,
    "Mutalisk/Guardian Cocoon": 59,
    "Corsair": 60,
    "Dark Templar (Unit)": 61,
    "Devourer": 62,
    "Dark Archon": 63,
    "Probe": 64,
    "Zealot": 65,
    "Dragoon": 66,
    "High Templar": 67,
    "Archon": 68,
    "Shuttle": 69,
    "Scout": 70,
    "Arbiter": 71,
    "Carrier": 72,
    "Interceptor": 73,
    "Dark Templar (Hero)": 74,
    "Zeratul": 75,
    "Zeratul (Dark Templar)": 75,
    "Tassadar/Zeratul": 76,
    "Tassadar/Zeratul (Archon)": 76,
    "Fenix (Zealot)": 77,
    "Fenix (Dragoon)": 78,
    "Tassadar": 79,
    "Tassadar (Templar)": 79,
    "Mojo": 80,
    "Mojo (Scout)": 80,
    "Warbringer": 81,
    "Warbringer (Reaver)": 81,
    "Gantrithor": 82,
    "Gantrithor (Carrier)": 82,
    "Reaver": 83,
    "Observer": 84,
    "Scarab": 85,
    "Danimoth": 86,
    "Danimoth (Arbiter)": 86,
    "Blank (Aldaris)": 87,
    "Artanis": 88,
    "Artanis (Scout)": 88,
    "Rhynadon": 89,
    "Rhynadon (Badlands Critter)": 89,
    "Bengalaas": 90,
    "Bengalaas (Jungle Critter)": 90,
    "Lurker (Cargo Ship - Unused)": 91,
    "Mercenary Gunship (Unused)": 92,
    "Scantid": 93,
    "Scantid (Desert Critter)": 93,
    "Kakaru": 94,
    "Kakaru (Twilight Critter)": 94,
    "Ragnasaur": 95,
    "Ragnasaur (Ashworld Critter)": 95,
    "Ursadon": 96,
    "Ursadon (Ice Critter)": 96,
    "Blank (Zerg Lurker Egg)": 97,
    "Blank (Raszagal)": 98,
    "Samir Duran": 99,
    "Samir Duran (Ghost)": 99,
    "Alexei Stukov": 100,
    "Alexei Stukov (Ghost)": 100,
    "Map Revealer": 101,
    "Blank (Gerard DuGalle)": 102,
    "Lurker": 103,
    "Infested Duran": 104,
    "Infested Duran (Infested Terran)": 104,
    "Blank (Disruption Field)": 105,
    "Command Center": 106,
    "Comsat Station": 107,
    "Nuclear Silo": 108,
    "Supply Depot": 109,
    "Refinery": 110,
    "Barracks": 111,
    "Academy": 112,
    "Factory": 113,
    "Starport": 114,
    "Control Tower": 115,
    "Science Facility": 116,
    "Covert Ops": 117,
    "Physics Lab": 118,
    "Blank (Starbase - Unused)": 119,
    "Machine Shop": 120,
    "Repair Bay (Unused)": 121,
    "Engineering Bay": 122,
    "Armory": 123,
    "Missile Tower": 124,
    "Bunker": 125,
    "Crashed Norad II": 126,
    "Ion Cannon": 127,
    "Uraj": 128,
    "Khalis": 129,
    "Infested Command Center": 130,
    "Hatchery": 131,
    "Lair": 132,
    "Hive": 133,
    "Nydus Canal": 134,
    "Hydralisk Den": 135,
    "Defiler Mound": 136,
    "Greater Spire": 137,
    "Queen's Nest": 138,
    "Evolution Chamber": 139,
    "Ultralisk Cavern": 140,
    "Spire": 141,
    "Spawning Pool": 142,
    "Creep Colony": 143,
    "Spore Colony": 144,
    "Radioactive (Zerg Bldg1 - Unused)": 145,
    "Sunken Colony": 146,
    "Overmind (Without Shell)": 147,
    "Overmind (With Shell)": 148,
    "Extractor": 149,
    "Mature Chrysalis": 150,
    "Cerebrate": 151,
    "Cerebrate Daggoth": 152,
    "Blank (Zerg Bldg2 - Unused)": 153,
    "Nexus": 154,
    "Robotics Facility": 155,
    "Pylon": 156,
    "Assimilator": 157,
    "Blank (Protoss Bldg1 - Unused)": 158,
    "Observatory": 159,
    "Gateway": 160,
    "Blank (Protoss Bldg2 - Unused)": 161,
    "Photon Cannon": 162,
    "Citadel of Adun": 163,
    "Cybernetics Core": 164,
    "Templar Archives": 165,
    "Forge": 166,
    "Stargate": 167,
    "Stasis Cell/Prison": 168,
    "Fleet Beacon": 169,
    "Arbiter Tribunal": 170,
    "Robotics Support Bay": 171,
    "Shield Battery": 172,
    "Khaydarin Crystal Formation": 173,
    "Protoss Temple": 174,
    "Xel'Naga Temple": 175,
    "Mineral Cluster (Type 1)": 176,
    "Mineral Cluster (Type 2)": 177,
    "Mineral Cluster (Type 3)": 178,
    "Blank (Cave - Unused)": 179,
    "Blank (Cave-in - Unused)": 180,
    "Blank (Cantina - Unused)": 181,
    "Blank (Mining Platform - Unused)": 182,
    "Blank (Independent CC - Unused)": 183,
    "Blank (Independent Starport - Unused)": 184,
    "Blank (Jump Gate - Unused)": 185,
    "Blank (Ruins - Unused)": 186,
    "Blank (Khayd. Crystal Form. - Unused)": 187,
    "Vespene Geyser": 188,
    "Warp Gate": 189,
    "Psi Disrupter": 190,
    "Blank (Zerg Marker)": 191,
    "Blank (Terran Marker)": 192,
    "Blank (Protoss Marker)": 193,
    "Zerg Beacon": 194,
    "Terran Beacon": 195,
    "Protoss Beacon": 196,
    "Zerg Flag Beacon": 197,
    "Terran Flag Beacon": 198,
    "Protoss Flag Beacon": 199,
    "Power Generator": 200,
    "Overmind Cocoon": 201,
    "Blank (Dark Swarm)": 202,
    "Blank (Floor Missile Trap)": 203,
    "Blank (Floor Hatch - Unused)": 204,
    "Blank (Left Upper Level Door)": 205,
    "Blank (Right Upper Level Door)": 206,
    "Blank (Left Pit Door)": 207,
    "Blank (Right Pit Door)": 208,
    "Blank (Floor Gun Trap)": 209,
    "Blank (Left Wall Missile Trap)": 210,
    "Blank (Left Wall Flame Trap)": 211,
    "Infested Mine (Unused)": 212,
    "Blank (Right Wall Flame Trap)": 213,
    "Start Location": 214,
    "Flag": 215,
    "Young Chrysalis": 216,
    "Psi Emitter": 217,
    "Data Disc": 218,
    "Khaydarin Crystal": 219,
    "Blank (Mineral Chunk Type 1)": 220,
    "Blank (Mineral Chunk Type 2)": 221,
    "Blank (Protoss Vespene Orb Type 1)": 222,
    "Blank (Protoss Vespene Orb Type 2)": 223,
    "Blank (Zerg Vespene Sac Type 1)": 224,
    "Blank (Zerg Vespene Sac Type 2)": 225,
    "Blank (Terran Vespene Tank Type 1)": 226,
    "Blank (Terran Vespene Tank Type 2)": 227,
    "Move": 228,
    "Stop": 229,
    "Attack": 230,
    "Gather": 231,
    "Repair": 232,
    "Return Resources": 233,
    "Terran Basic Buildings": 234,
    "Terran Advanced Buildings": 235,
    "Cancel": 236,
    "Use Stimpack": 237,
    "U-238 Shells": 238,
    "Burst Lasers (Unused)": 239,
    "Lockdown": 240,
    "EMP Shockwave": 241,
    "Irradiate": 242,
    "Use Spider Mines": 243,
    "Afterburners (Unused Terran Upgrade)": 244,
    "Siege Mode": 245,
    "Tank Mode": 246,
    "Defensive Matrix": 247,
    "Titan Reactor": 248,
    "Ocular Implants": 249,
    "Scanner Sweep": 250,
    "Yamato Gun": 251,
    "Cloak": 252,
    "Decloak": 253,
    "Patrol": 254,
    "Hold Position": 255,
    "Moebius Reactor": 256,
    "Zerg Basic Buildings": 257,
    "Zerg Advanced Buildings": 258,
    "Burrow": 259,
    "Unburrow": 260,
    "Ventral Sacs": 261,
    "Antennae": 262,
    "Metabolic Boost": 263,
    "Adrenal Glands": 264,
    "Plague": 265,
    "Muscular Augments": 266,
    "Ensnare": 267,
    "Grooved Spines": 268,
    "Roar (Unused Zerg Upgrade)": 269,
    "Dark Swarm": 270,
    "Parasite": 271,
    "Protoss Basic Buildings": 272,
    "Protoss Advanced Buildings": 273,
    "Mind Control (SC Beta - Unused)": 274,
    "Psionic Storm": 275,
    "Gravitic Boosters": 276,
    "Hallucination": 277,
    "Stasis Field": 278,
    "Blank": 279,
    "Recall": 280,
    "Singularity Charge": 281,
    "Lift off": 282,
    "Land": 283,
    "Apollo Reactor": 284,
    "Colossus Reactor": 285,
    "Set Rally Point": 286,
    "Ion Thrusters": 287,
    "Infantry Weapons": 288,
    "Vehicle Weapons": 289,
    "Ship Weapons": 290,
    "Ship Plating": 291,
    "Infantry Armor": 292,
    "Vehicle Armor": 293,
    "Gamete Meiosis": 294,
    "Metasynaptic Node": 295,
    "Pneumatized Caparace": 296,
    "Zerg Caparace": 297,
    "Flyer Caparace": 298,
    "Melee Attacks": 299,
    "Missile Attacks": 300,
    "Flyer Attacks": 301,
    "Consume": 302,
    "Ground Armor": 303,
    "Air Plating": 304,
    "Ground Weapons": 305,
    "Air Weapons": 306,
    "Leg Enhancements": 307,
    "Recharge Shields": 308,
    "Load (into Transport)": 309,
    "Plasma Shields": 310,
    "Nuclear Strike": 311,
    "Unload All (from Transport/Bunker)": 312,
    "Infest Command Center": 313,
    "Scarab Damage": 314,
    "Reaver Capacity": 315,
    "Gravitic Drive": 316,
    "Sensor Array": 317,
    "Khaydarin Amulet": 318,
    "Apial Sensors": 319,
    "Gravitic Thrusters": 320,
    "Carrier Capacity": 321,
    "Khaydarin Core": 322,
    "Gauss Rifle": 323,
    "C-10 Canister Rifle": 324,
    "Fragmentation Grenade": 325,
    "Twin Autocannons": 326,
    "Hellfire Missile Pack": 327,
    "Arclite Cannon": 328,
    "Fusion Cutter": 329,
    "Fusion Cutter (Harvest)": 330,
    "Gemini Missiles": 331,
    "Burst Lasers": 332,
    "ATS Laser Battery": 333,
    "ATA Laser Battery": 334,
    "Flame Thrower": 335,
    "Arclite Shock Cannon": 336,
    "Longbolt Missile": 337,
    "Claws": 338,
    "Needle Spines": 339,
    "Kaiser Blades": 340,
    "Toxic Spores": 341,
    "Spines": 342,
    "Flyer Attack": 343,
    "Acid Spore": 344,
    "Glave Wurm": 345,
    "Venom (Unused Zerg Weapon)": 346,
    "Seeker Spores": 347,
    "Subterranean Tentacle": 348,
    "Suicide (Infested Terran)": 349,
    "Suicide (Scourge)": 350,
    "Particle Beam": 351,
    "Particle Beam (Harvest)": 352,
    "Psi/Warp Blades": 353,
    "Phase Disruptor": 354,
    "Psi Assault": 355,
    "Psionic Shockwave": 356,
    "Radioactive (Unused)": 357,
    "Dual Photon Blasters": 358,
    "Anti-matter Missiles": 359,
    "Phase Disruptor Cannon": 360,
    "Pulse Cannon": 361,
    "STS/STA Photon Cannon": 362,
    "Radioactive (Unused2)": 363,
    "Spider Mine": 364,
    "Heal": 365,
    "Restoration": 366,
    "Restoration2": 367,
    "Disruption Web": 368,
    "Disruption Web2": 369,
    "Unknown371": 370,
    "Mind Control": 371,
    "Feedback": 372,
    "Optical Flare": 373,
    "Afterburners ON (Unused)": 374,
    "Afterburners OFF (Unused)": 375,
    "Lurker Aspect": 376,
    "Unknown378": 377,
    "Anabolic Synthesis": 378,
    "Chitinous Plating": 379,
    "Charon Boosters": 380,
    "Maelstrom": 381,
    "Subterranean Spines": 382,
    "Argus Jewel": 383,
    "Caduceus Reactor": 384,
    "Argus Talisman": 385,
    "Play (Replay)": 386,
    "Pause (Replay)": 387,
    "Speed Up (Replay)": 388,
    "Slow Down (Replay)": 389,
}

DefaultIcon: TypeAlias = Literal[
    "Marine",
    "Ghost",
    "Vulture",
    "Goliath",
    "Blank (Goliath Turret)",
    "Siege Tank (Tank Mode)",
    "Blank (Tank Turret)",
    "SCV",
    "Wraith",
    "Science Vessel",
    "Gui Montag",
    "Dropship",
    "Battlecruiser",
    "Vulture Spider Mine",
    "Nuclear Missile",
    "Civilian",
    "Sarah Kerrigan",
    "Alan Schezar",
    "Blank (Alan Turret)",
    "Jim Raynor (Vulture)",
    "Jim Raynor (Marine)",
    "Tom Kazansky",
    "Magellan",
    "Edmund Duke (Siege Tank)",
    "Blank (Duke Turret)",
    "Edmund Duke (Siege Mode)",
    "Blank (Siege Duke Turret)",
    "Blank (Arcturus Mengsk)",
    "Hyperion",
    "Norad II (Battlecruiser)",
    "Terran Siege Tank (Siege Mode)",
    "Blank (Siege Tank Turret)",
    "Firebat",
    "Marine (Scanner Sweep)",
    "Medic",
    "Larva",
    "Radioactive (Zerg Egg)",
    "Zergling",
    "Hydralisk",
    "Ultralisk",
    "Broodling",
    "Drone",
    "Overlord",
    "Mutalisk",
    "Guardian",
    "Queen",
    "Defiler",
    "Scourge",
    "Torrarsque",
    "Matriarch",
    "Infested Terran",
    "Infested Kerrigan",
    "Unclean One",
    "Hunter Killer",
    "Devouring One",
    "Kukulza (Mutalisk)",
    "Kukulza (Guardian)",
    "Yggdrasill",
    "Valkyrie",
    "Mutalisk/Guardian Cocoon",
    "Corsair",
    "Dark Templar (Unit)",
    "Devourer",
    "Dark Archon",
    "Probe",
    "Zealot",
    "Dragoon",
    "High Templar",
    "Archon",
    "Shuttle",
    "Scout",
    "Arbiter",
    "Carrier",
    "Interceptor",
    "Dark Templar (Hero)",
    "Zeratul",
    "Tassadar/Zeratul",
    "Fenix (Zealot)",
    "Fenix (Dragoon)",
    "Tassadar",
    "Mojo",
    "Warbringer",
    "Gantrithor",
    "Reaver",
    "Observer",
    "Scarab",
    "Danimoth",
    "Blank (Aldaris)",
    "Artanis",
    "Rhynadon",
    "Bengalaas",
    "Lurker (Cargo Ship - Unused)",
    "Mercenary Gunship (Unused)",
    "Scantid",
    "Kakaru",
    "Ragnasaur",
    "Ursadon",
    "Blank (Zerg Lurker Egg)",
    "Blank (Raszagal)",
    "Samir Duran",
    "Alexei Stukov",
    "Map Revealer",
    "Blank (Gerard DuGalle)",
    "Lurker",
    "Infested Duran",
    "Blank (Disruption Field)",
    "Command Center",
    "Comsat Station",
    "Nuclear Silo",
    "Supply Depot",
    "Refinery",
    "Barracks",
    "Academy",
    "Factory",
    "Starport",
    "Control Tower",
    "Science Facility",
    "Covert Ops",
    "Physics Lab",
    "Blank (Starbase - Unused)",
    "Machine Shop",
    "Repair Bay (Unused)",
    "Engineering Bay",
    "Armory",
    "Missile Tower",
    "Bunker",
    "Crashed Norad II",
    "Ion Cannon",
    "Uraj",
    "Khalis",
    "Infested Command Center",
    "Hatchery",
    "Lair",
    "Hive",
    "Nydus Canal",
    "Hydralisk Den",
    "Defiler Mound",
    "Greater Spire",
    "Queen's Nest",
    "Evolution Chamber",
    "Ultralisk Cavern",
    "Spire",
    "Spawning Pool",
    "Creep Colony",
    "Spore Colony",
    "Radioactive (Zerg Bldg1 - Unused)",
    "Sunken Colony",
    "Overmind (Without Shell)",
    "Overmind (With Shell)",
    "Extractor",
    "Mature Chrysalis",
    "Cerebrate",
    "Cerebrate Daggoth",
    "Blank (Zerg Bldg2 - Unused)",
    "Nexus",
    "Robotics Facility",
    "Pylon",
    "Assimilator",
    "Blank (Protoss Bldg1 - Unused)",
    "Observatory",
    "Gateway",
    "Blank (Protoss Bldg2 - Unused)",
    "Photon Cannon",
    "Citadel of Adun",
    "Cybernetics Core",
    "Templar Archives",
    "Forge",
    "Stargate",
    "Stasis Cell/Prison",
    "Fleet Beacon",
    "Arbiter Tribunal",
    "Robotics Support Bay",
    "Shield Battery",
    "Khaydarin Crystal Formation",
    "Protoss Temple",
    "Xel'Naga Temple",
    "Mineral Cluster (Type 1)",
    "Mineral Cluster (Type 2)",
    "Mineral Cluster (Type 3)",
    "Blank (Cave - Unused)",
    "Blank (Cave-in - Unused)",
    "Blank (Cantina - Unused)",
    "Blank (Mining Platform - Unused)",
    "Blank (Independent CC - Unused)",
    "Blank (Independent Starport - Unused)",
    "Blank (Jump Gate - Unused)",
    "Blank (Ruins - Unused)",
    "Blank (Khayd. Crystal Form. - Unused)",
    "Vespene Geyser",
    "Warp Gate",
    "Psi Disrupter",
    "Blank (Zerg Marker)",
    "Blank (Terran Marker)",
    "Blank (Protoss Marker)",
    "Zerg Beacon",
    "Terran Beacon",
    "Protoss Beacon",
    "Zerg Flag Beacon",
    "Terran Flag Beacon",
    "Protoss Flag Beacon",
    "Power Generator",
    "Overmind Cocoon",
    "Blank (Dark Swarm)",
    "Blank (Floor Missile Trap)",
    "Blank (Floor Hatch - Unused)",
    "Blank (Left Upper Level Door)",
    "Blank (Right Upper Level Door)",
    "Blank (Left Pit Door)",
    "Blank (Right Pit Door)",
    "Blank (Floor Gun Trap)",
    "Blank (Left Wall Missile Trap)",
    "Blank (Left Wall Flame Trap)",
    "Infested Mine (Unused)",
    "Blank (Right Wall Flame Trap)",
    "Start Location",
    "Flag",
    "Young Chrysalis",
    "Psi Emitter",
    "Data Disc",
    "Khaydarin Crystal",
    "Blank (Mineral Chunk Type 1)",
    "Blank (Mineral Chunk Type 2)",
    "Blank (Protoss Vespene Orb Type 1)",
    "Blank (Protoss Vespene Orb Type 2)",
    "Blank (Zerg Vespene Sac Type 1)",
    "Blank (Zerg Vespene Sac Type 2)",
    "Blank (Terran Vespene Tank Type 1)",
    "Blank (Terran Vespene Tank Type 2)",
    "Move",
    "Stop",
    "Attack",
    "Gather",
    "Repair",
    "Return Resources",
    "Terran Basic Buildings",
    "Terran Advanced Buildings",
    "Cancel",
    "Use Stimpack",
    "U-238 Shells",
    "Burst Lasers (Unused)",
    "Lockdown",
    "EMP Shockwave",
    "Irradiate",
    "Use Spider Mines",
    "Afterburners (Unused Terran Upgrade)",
    "Siege Mode",
    "Tank Mode",
    "Defensive Matrix",
    "Titan Reactor",
    "Ocular Implants",
    "Scanner Sweep",
    "Yamato Gun",
    "Cloak",
    "Decloak",
    "Patrol",
    "Hold Position",
    "Moebius Reactor",
    "Zerg Basic Buildings",
    "Zerg Advanced Buildings",
    "Burrow",
    "Unburrow",
    "Ventral Sacs",
    "Antennae",
    "Metabolic Boost",
    "Adrenal Glands",
    "Plague",
    "Muscular Augments",
    "Ensnare",
    "Grooved Spines",
    "Roar (Unused Zerg Upgrade)",
    "Dark Swarm",
    "Parasite",
    "Protoss Basic Buildings",
    "Protoss Advanced Buildings",
    "Mind Control (SC Beta - Unused)",
    "Psionic Storm",
    "Gravitic Boosters",
    "Hallucination",
    "Stasis Field",
    "Blank",
    "Recall",
    "Singularity Charge",
    "Lift off",
    "Land",
    "Apollo Reactor",
    "Colossus Reactor",
    "Set Rally Point",
    "Ion Thrusters",
    "Infantry Weapons",
    "Vehicle Weapons",
    "Ship Weapons",
    "Ship Plating",
    "Infantry Armor",
    "Vehicle Armor",
    "Gamete Meiosis",
    "Metasynaptic Node",
    "Pneumatized Caparace",
    "Zerg Caparace",
    "Flyer Caparace",
    "Melee Attacks",
    "Missile Attacks",
    "Flyer Attacks",
    "Consume",
    "Ground Armor",
    "Air Plating",
    "Ground Weapons",
    "Air Weapons",
    "Leg Enhancements",
    "Recharge Shields",
    "Load (into Transport)",
    "Plasma Shields",
    "Nuclear Strike",
    "Unload All (from Transport/Bunker)",
    "Infest Command Center",
    "Scarab Damage",
    "Reaver Capacity",
    "Gravitic Drive",
    "Sensor Array",
    "Khaydarin Amulet",
    "Apial Sensors",
    "Gravitic Thrusters",
    "Carrier Capacity",
    "Khaydarin Core",
    "Gauss Rifle",
    "C-10 Canister Rifle",
    "Fragmentation Grenade",
    "Twin Autocannons",
    "Hellfire Missile Pack",
    "Arclite Cannon",
    "Fusion Cutter",
    "Fusion Cutter (Harvest)",
    "Gemini Missiles",
    "Burst Lasers",
    "ATS Laser Battery",
    "ATA Laser Battery",
    "Flame Thrower",
    "Arclite Shock Cannon",
    "Longbolt Missile",
    "Claws",
    "Needle Spines",
    "Kaiser Blades",
    "Toxic Spores",
    "Spines",
    "Flyer Attack",
    "Acid Spore",
    "Glave Wurm",
    "Venom (Unused Zerg Weapon)",
    "Seeker Spores",
    "Subterranean Tentacle",
    "Suicide (Infested Terran)",
    "Suicide (Scourge)",
    "Particle Beam",
    "Particle Beam (Harvest)",
    "Psi/Warp Blades",
    "Phase Disruptor",
    "Psi Assault",
    "Psionic Shockwave",
    "Radioactive (Unused)",
    "Dual Photon Blasters",
    "Anti-matter Missiles",
    "Phase Disruptor Cannon",
    "Pulse Cannon",
    "STS/STA Photon Cannon",
    "Radioactive (Unused2)",
    "Spider Mine",
    "Heal",
    "Restoration",
    "Restoration2",
    "Disruption Web",
    "Disruption Web2",
    "Unknown371",
    "Mind Control",
    "Feedback",
    "Optical Flare",
    "Afterburners ON (Unused)",
    "Afterburners OFF (Unused)",
    "Lurker Aspect",
    "Unknown378",
    "Anabolic Synthesis",
    "Chitinous Plating",
    "Charon Boosters",
    "Maelstrom",
    "Subterranean Spines",
    "Argus Jewel",
    "Caduceus Reactor",
    "Argus Talisman",
    "Play (Replay)",
    "Pause (Replay)",
    "Speed Up (Replay)",
    "Slow Down (Replay)",
]



from typing import Literal, TypeAlias

DefUnitOrderDict: dict[str, int] = {
    # Causes the unit to die. Normal units run the death iscript animation.
    "Die": 0,
    # while hallucinated units have the sound/sprite spawned and then are removed.
    # Normal unit stop command. Stops current order chain, and then goes to idle.
    "Stop": 1,
    "Guard": 2,  # Generic Guard order. Determines what guard command a unit uses.
    "Guard (Normal)": 2,
    "Guard (Player)": 3,  # Attacking Mobile unit guard order.
    "Guard (Subunit)": 4,  # Attacking unit turret guard.
    # Transport building guard. Set when a building picks up a unit.
    "Guard (Bunker)": 5,
    "Move": 6,  # Unit move. Ignores enemies on way to destination.
    "Ignore (Normal)": 6,
    "Reaver Stop": 7,  # Stop order for the reaver.
    "Stop (Reaver)": 7,
    "Attack": 8,  # Generic attack order.
    "Attack Obscured": 9,  # Move to attack shrouded building.
    "Attack Unit": 10,  # Mobile unit attacking a unit/building.
    "Attack Unit (Normal)": 10,
    "Attack In Range": 11,  # Attack for an immobile unit. Lurker attack.
    "Attack Ground (Unused)": 12,
    "Hover (Unused)": 13,
    "Attack Move": 14,  # Unit move, attack enemies along path to target.
    "Building Is Being Infested": 15,  # Ran when a unit is being infested.
    "Nothing 1 (Unused)": 16,  # Unknown
    "Power-Up (Unused)": 17,  # Unknown. Speculated to be a Powerup being built order
    "Guard (Building)": 18,  # Building tower guard.
    "Attack (Building)": 19,  # Building tower attack.
    "Script (Spider Mine)": 20,  # Spider mine idle order.
    "Stay In Range": 21,  # Mobile unit base attack.
    "Attack (Subunit)": 22,  # Mobile Unit Turret attack.
    "Nothing 2 (Normal)": 23,  # Do nothing, next order.
    # Unknown, used when a unit is changing state between siege <-> normal.
    "Nothing 3 (Unused)": 24,
    "Drone Start Build": 25,  # Move to target position and run drone build.
    "Drone Start Mutate": 25,
    "Drone Build": 26,  # Check resources and run drone land.
    "Drone Mutate": 26,
    "Cast Infest": 27,  # Move to Infest a unit.
    "Cast Spell (Infest 1)": 27,
    "Cast Infest Obscured": 28,  # Move to Infest shrouded unit
    "Cast Spell (Infest 2)": 28,
    # Infest Unit. Hides unit, runs infest 1 on target, then reshows unit.
    "Start Infest": 29,
    "Infest (Queen)": 29,
    "Build (SCV)": 30,  # Move/Start Terran Building.
    "Build (Probe)": 31,  # Full Protoss Building order.
    "Create Building (Probe)": 32,  # Creates the Protoss Building.
    "Is Building (SCV)": 33,  # SCV is building.
    "Repair Unit (SCV)": 34,  # Repair Unit.
    "Repair Unit Obscured (SCV)": 35,  # Move to repair shrouded building.
    "Place Add-On": 36,  # Move and start addon.
    "Build Add-On": 37,  # Building Addon.
    "Train": 38,  # Training Unit.
    "Train (Normal)": 38,
    # Rally to Visible Unit. Causes units to follow the selected unit.
    "Rally to Visible Unit": 39,
    "Rally to Ground Tile": 40,  # Rally to tile.
    "Zerg Birth": 41,  # Unit is being born.
    "Unit Morph": 42,  # Unit Morph
    "Building Morph": 43,  # Building Morph
    "Building Is Constructed (Terran)": 44,  # Terran Building, Is being built.
    "Zerg Build Self": 45,  # Zerg Building build order.
    "Build (Nydus Canal Exit)": 46,  # Nydus canal exit build order.
    "Enter (Nydus Canal)": 47,  # Enter/transport through nydus canal
    "Building Is Constructed (Protoss)": 48,  # Protoss Building being built order.
    # Move to/with unit or building. Causes units to load into transports
    "Follow": 49,  # or enter nydus canal or recharge shields.
    "Idle (Carrier)": 50,  # Idle command for the carrier.
    "Move (Carrier&Reaver)": 51,  # Carrier move command. Ignores enemies
    "Stop (Carrier)": 52,  # Carrier stop command. Runs idle.
    "Attack (Carrier)": 53,  # Generic Carrier attack command.
    "Attack Obscured (Carrier)": 54,  # Move to attack shrouded building.
    "Ignore 2 (Carrier)": 55,  # Unknown. Possibly a secondary move.
    "Attack Unit (Carrier)": 56,  # Carrier Attack Unit.
    "Hold Position (Carrier)": 57,  # Carrier Hold Position.
    "Idle (Reaver)": 58,  # Reaver Idle order.
    "Attack (Reaver)": 59,  # Generic reaver attack order.
    "Attack Obscured (Reaver)": 60,  # Move to attack shrouded building
    "Attack Unit (Reaver)": 61,  # Reaver attack unit.
    "Hold Position (Reaver)": 62,  # Reaver hold position.
    "Train Fighter": 63,  # Training subunit(scarab, interceptor).
    # Causes all interceptors within a carrier to be healed when not attacking.
    "Training (Subunit)": 63,
    "Move&Attack (Interceptor)": 64,  # Interceptor move and attack.
    "Move&Attack (Scarab)": 65,  # Scarab move and attack.
    "Recharge Shields (Unit)": 66,  # Unit recharge shields.
    # Shield Battery, recharge shield cast on unit or ground.
    # Unit runs Recharge Shields (Unit),
    # shield battery runs "Shield Battery Is Recharging".
    # If cast on ground, recharges all units within rechargeable radius.
    "Recharge Shields (Global)": 67,
    "Shield Battery Is Recharging": 68,  # Shield Battery, is recharging.
    "Return To Parent (Interceptor)": 69,  # Interceptor return to parent.
    "Land (Drone)": 70,  # Drone landing order. Used when building.
    "Land (Building)": 71,  # Building land order.
    "Lift Off (Building)": 72,  # Begin Building Liftoff
    "Lift Off (Drone)": 73,  # Begin Drone liftoff
    "Is Lifting Off": 74,  # Unit is lifting off.
    "Research Tech": 75,  # Building researching tech.
    "Is Researching Technology": 75,
    "Research Upgrade": 76,  # Building researching upgrade.
    "Is Performing Upgrade": 76,
    "Idle (Larva)": 77,  # Idle order for larva. Make sure it stays on creep,
    # dies if off, and says within the range of the parent it came from.
    "Is Spawning Larva": 78,  # Building is spawning larva.
    "Move to Harvest": 79,  # Generic move to harvest order.
    "Move to Harvest Obscured": 80,  # Move to harvest shrouded minerals/gas
    "Move to Harvest Gas": 81,  # Move to harvest gas.
    "Can Enter Gas Mine": 82,  # Check if it can enter the gas mine(no unit in it).
    "Enter/Exit Gas Mine": 83,  # Enter/exit mine, set return order.
    "Return Gas": 84,  # Return order, has gas.
    "Move to Harvest Minerals": 85,  # Move to harvest minerals.
    "Can Harvest Minerals": 86,  # Can harvest minerals(one unit per field).
    "Harvesting Minerals": 87,  # Harvesting minerals. Runs iscript to spawn weapon.
    "Harvesting Minerals Interrupted": 88,  # Harvesting minerals is interrupted.
    "Harvest 4 (Unknown)": 89,  # Unknown harvest command.
    "Return Minerals": 90,  # Return resources /B Has minerals.
    # Harvest Interrupt /B recharge shields.
    "Harvesting Interrupted - Recharge Shields": 91,
    "Move/Enter Transport": 92,  # Move/enter a transport.
    "Idle (Transport)": 93,  # Transport Idle command.
    "Load Unit (Mobile Transport)": 94,  # Mobile Transport unit pickup.
    "Load Unit (Bunker)": 95,  # Building pickup.
    "Load Unit (Unknown)": 96,  # Unknown /B AI pickup?
    "Idle (Power-Up)": 97,  # Idle for powerups.
    "Siege Mode": 98,  # Switch to Siege mode.
    "Tank Mode": 99,  # Switch to Tank mode.
    "Watch Target": 100,  # Immobile Unit base, watch the target.
    "Script (Starting Creep Growth)": 101,  # Start Spreading Creep.
    # Spreads creep. If it is a larva producer, runs that order also.
    "Script (Spread Creep&Spawn Larva)": 102,
    "Script (Stopping Creep Growth)": 103,  # Stops creep growth.
    "Guardian Aspect (Unused)": 104,  # Unused, Unit Morph is used for unit morphing.
    "Move and Merge Archon": 105,  # Move and start archon merge.
    "Move and Morph Archon": 105,
    "Completing Archon Summon": 106,  # Archon build self order.
    "Hold Position": 107,  # Attacking Unit hold position.
    "Hold Position (Normal)": 107,
    "Hold Position (Queen)": 108,  # Queen Hold position.
    "Cloak": 109,  # Cloak Unit.
    "Decloak": 110,  # Decloak Unit.
    "Unload": 111,  # Unload a unit from the transport.
    "Unload Unit (Transport)": 111,
    "Move and Unload": 112,  # Move to unload site and run unload order.
    "Move&Unload Unit (Transport)": 112,
    "Cast Yamato Gun": 113,  # Cast Spell: Yamato.
    "Cast Spell (Yamato Gun)": 113,
    "Cast Yamato Gun Obscured": 114,  # Move to cast spell on shrouded building.
    "Cast Spell On Obscured (Yamato Gun)": 114,
    "Cast Lockdown": 115,  # Cast Spell: Lockdown.
    "Cast Spell (Lockdown)": 115,
    "Burrow": 116,  # Burrow Unit.
    "Idle (Burrowed)": 117,  # Burrowed Unit idle.
    "Unburrow": 118,  # Unburrow unit.
    "Cast Dark Swarm": 119,  # Cast Spell: Dark Swarm.
    "Cast Spell (Dark Swarm)": 119,
    "Cast Parasite": 120,  # Cast Spell: Parasite.
    "Cast Spell (Parasite)": 120,
    "Cast Broodling": 121,  # Cast Spell: Spawn Broodings.
    "Cast Spell (Spawn Broodling)": 121,
    "Cast EMP Shockwave": 122,  # Cast Spell: EMP Shockwave.
    "Cast Spell (EMP Shockwave)": 122,
    "Nuke Wait": 123,  # Unknown.
    "Nuke Train": 124,  # Silo Idle
    "Idle (Nuclear Silo)": 124,
    "Nuke Launch": 125,  # Launch for nuclear missile.
    "Attack (Nuke)": 125,
    "Move&Paint Nuke Target": 126,  # Move to and set nuke target.
    "Attack Unit (Nuke)": 127,  # Nuke the ground location of the unit.
    "Attack Ground (Nuke)": 128,  # Nuke ground.
    "Nuke Track (Ghost)": 129,  # Ghost order during nuke.
    "Init Cloaking Field": 130,  # Run nearby cloaking.
    "Script (Cloak Nearby Units)": 130,
    "Cloaking Field": 131,  # Cloak non arbiters within range.
    "Cloak Nearby Units (Freezes the casting unit)": 131,
    "Place Spider Mine": 132,  # Place spider mine.
    "Right Click Action": 133,  # right click, sets correct order based on target.
    "Script (Right-Click Action)": 133,
    "Attack Unit (Infested Terran)": 134,  # Suicide Attack Unit.
    "Attack Ground (Infested Terran)": 135,  # Suicide Attack tile.
    "Hold Position (Suicide Units)": 136,  # Suicide Hold Position.
    "Cast Recall": 137,  # Recall(units within range of target pos).
    "Cast Spell (Recall)": 137,
    "Recall to Location": 138,  # Causes units to teleport when being recalled.
    "Teleport To Location (Freezes the casting unit)": 138,
    "Cast Scanner Sweep": 139,  # Place Scanner Sweep Unit at position.
    "Cast Spell (Scanner Sweep)": 139,
    "Idle (Scanner Sweep)": 140,  # Scanner Sweep Unit idle.
    "Cast Defensive Matrix": 141,  # Defensive Matrix cast on target.
    "Cast Spell (Defensive Matrix)": 141,
    "Cast Psionic Storm": 142,  # Cast Spell: Psi Storm.
    "Cast Spell (Psionic Storm)": 142,
    "Cast Irradiate": 143,  # Cast Spell: Irradiate.
    "Cast Spell (Irradiate)": 143,
    "Cast Plague": 144,  # Cast Spell: Plague.
    "Cast Spell (Plague)": 144,
    "Cast Consume": 145,  # Cast Spell: Consume.
    "Cast Spell (Consume)": 145,
    "Cast Ensnare": 146,  # Cast Spell: Ensnare.
    "Cast Spell (Ensnare)": 146,
    "Cast Stasis Field": 147,  # Cast Spell: Stasis Field.
    "Cast Spell (Stasis Field)": 147,
    "Cast Hallucination": 148,  # Hallucination Cast on target.
    "Cast Spell (Hallucination)": 148,
    "Kill Hallucination on Spell": 149,  # Kill Halluciation on spell cast.
    "Script (Hallucination)": 149,
    "Reset Collision (2 Units)": 150,  # Collision Reset between 2 units.
    # Collision reset between harvester and mine.
    "Reset Collision (Harvester&Mine)": 151,
    "Patrol": 152,  # Patrol to target, queue patrol to original position.
    "Patrol (Normal)": 152,
    "CTF COP (Initialize)": 153,  # CTF Initialization
    "Idle (CTF COP)": 154,  # CTF Idle
    "Unknown CTF COP 2": 155,  # Unknown? Reset COP?
    "Script (Computer)": 156,  # AI Control.
    "Attack Move (Computer)": 157,  # AI Attack Move?
    # Aggressive Attack Move? Units won't give up on a target.
    # If they see it, they will attack it, even worse than attack move.
    "Move (Harass)": 158,  # Might be a computer attack move?
    # Moves units to the center of the current area that they are at?
    # Not sure if the spacing is meant to allow for detectors to cover an area or not.  # noqa: E501
    "Patrol (Computer)": 159,
    "Guard Post": 160,  # Immobile Unit Guard.
    "Guard (Computer)": 160,
    "Rescuable Passive": 161,  # Rescuable unit idle.
    "Idle (Rescuable)": 161,
    "Idle (Neutral)": 162,  # Neutral Unit idle.
    # Return computer units to defensive position?
    # Was seen returning units that had followed a unit outside of a base and killed it.  # noqa: E501
    "Return To Base (Computer)": 163,
    "Init Psi Provider": 164,  # Adds to some kind of linked list.
    "Script (PSI Provider)": 164,
    "Self Destrucing": 165,  # Remove unit.
    "Fatal (Scarab)": 165,
    "Idle (Critter)": 166,  # Critter idle.
    "Hidden Trap": 167,  # Trap idle order.
    "Idle (Trap)": 167,
    "Open Door": 168,  # Opens the door.
    "Close Door": 169,  # Closes the door.
    "Hide Trap": 170,  # Trap return to idle.
    "Stop (Trap)": 170,
    "Reveal Trap": 171,  # Trap attack.
    "Attack (Trap)": 171,
    "Enable Doodad": 172,  # Enable Doodad State.
    "Disable Doodad": 173,  # Disable Doodad State.
    # Unused. Left over from unit warp in which now exists in Starcraft 2.
    "Warp In (Unused)": 174,
    "Idle (Medic)": 175,  # Idle command for the Terran Medic.
    "Cast Heal": 176,  # Heal cast on target.
    "Cast Spell (Heal)": 176,
    "Heal Move": 177,  # Attack move command for the Terran Medic.
    "Move (Medic)": 177,
    # Holds Position for Terran Medics, heals units within range.
    "Hold Position&Heal": 178,
    "Hold Position&Heal (Medic)": 178,
    "Return To Idle After Heal": 179,  # Return to idle after heal.
    "Cast Restoration": 180,  # Cast Spell: Restoration.
    "Cast Spell (Restoration)": 180,
    "Cast Disruption Web": 181,  # Cast Spell: Disruption Web.
    "Cast Spell (Disruption Web)": 181,
    "Cast Mind Control": 182,  # Mind Control Cast on Target.
    "Cast Spell (Mind Control)": 182,
    "Dark Archon Meld": 183,  # Dark Archon Meld.
    "Cast Feedback": 184,  # Feedback cast on target.
    "Cast Spell (Feedback)": 184,
    "Cast Optical Flare": 185,  # Cast Spell: Optical Flare.
    "Cast Spell (Optical Flare)": 185,
    "Cast Maelstrom": 186,  # Cast Spell: Maelstrom.
    "Cast Spell (Maelstrom)": 186,
    "Junk Yard Dog": 187,  # Junk yard dog movement.
    "Move (Junk Yard Dog)": 187,
    "Fatal": 188,  # Nothing.
}

DefaultUnitOrder: TypeAlias = Literal[
    "Die",
    "Stop",
    "Guard",
    "Guard (Player)",
    "Guard (Subunit)",
    "Guard (Bunker)",
    "Move",
    "Stop (Reaver)",
    "Attack",
    "Attack Obscured",
    "Attack Unit",
    "Attack In Range",
    "Attack Ground (Unused)",
    "Hover (Unused)",
    "Attack Move",
    "Building Is Being Infested",
    "Nothing 1 (Unused)",
    "Power-Up (Unused)",
    "Guard (Building)",
    "Attack (Building)",
    "Script (Spider Mine)",
    "Stay In Range",
    "Attack (Subunit)",
    "Nothing 2 (Normal)",
    "Nothing 3 (Unused)",
    "Drone Start Build",
    "Drone Build",
    "Cast Infest",
    "Cast Infest Obscured",
    "Start Infest",
    "Build (SCV)",
    "Build (Probe)",
    "Create Building (Probe)",
    "Is Building (SCV)",
    "Repair Unit (SCV)",
    "Repair Unit Obscured (SCV)",
    "Place Add-On",
    "Build Add-On",
    "Train",
    "Rally to Visible Unit",
    "Rally to Ground Tile",
    "Zerg Birth",
    "Unit Morph",
    "Building Morph",
    "Building Is Constructed (Terran)",
    "Zerg Build Self",
    "Build (Nydus Canal Exit)",
    "Enter (Nydus Canal)",
    "Building Is Constructed (Protoss)",
    "Follow",
    "Idle (Carrier)",
    "Move (Carrier&Reaver)",
    "Stop (Carrier)",
    "Attack (Carrier)",
    "Attack Obscured (Carrier)",
    "Ignore 2 (Carrier)",
    "Attack Unit (Carrier)",
    "Hold Position (Carrier)",
    "Idle (Reaver)",
    "Attack (Reaver)",
    "Attack Obscured (Reaver)",
    "Attack Unit (Reaver)",
    "Hold Position (Reaver)",
    "Train Fighter",
    "Move&Attack (Interceptor)",
    "Move&Attack (Scarab)",
    "Recharge Shields (Unit)",
    "Recharge Shields (Global)",
    "Shield Battery Is Recharging",
    "Return To Parent (Interceptor)",
    "Land (Drone)",
    "Land (Building)",
    "Lift Off (Building)",
    "Lift Off (Drone)",
    "Is Lifting Off",
    "Research Tech",
    "Research Upgrade",
    "Idle (Larva)",
    "Is Spawning Larva",
    "Move to Harvest",
    "Move to Harvest Obscured",
    "Move to Harvest Gas",
    "Can Enter Gas Mine",
    "Enter/Exit Gas Mine",
    "Return Gas",
    "Move to Harvest Minerals",
    "Can Harvest Minerals",
    "Harvesting Minerals",
    "Harvesting Minerals Interrupted",
    "Harvest 4 (Unknown)",
    "Return Minerals",
    "Harvesting Interrupted - Recharge Shields",
    "Move/Enter Transport",
    "Idle (Transport)",
    "Load Unit (Mobile Transport)",
    "Load Unit (Bunker)",
    "Load Unit (Unknown)",
    "Idle (Power-Up)",
    "Siege Mode",
    "Tank Mode",
    "Watch Target",
    "Script (Starting Creep Growth)",
    "Script (Spread Creep&Spawn Larva)",
    "Script (Stopping Creep Growth)",
    "Guardian Aspect (Unused)",
    "Move and Merge Archon",
    "Completing Archon Summon",
    "Hold Position",
    "Hold Position (Queen)",
    "Cloak",
    "Decloak",
    "Unload",
    "Move and Unload",
    "Cast Yamato Gun",
    "Cast Yamato Gun Obscured",
    "Cast Lockdown",
    "Burrow",
    "Idle (Burrowed)",
    "Unburrow",
    "Cast Dark Swarm",
    "Cast Parasite",
    "Cast Broodling",
    "Cast EMP Shockwave",
    "Nuke Wait",
    "Idle (Nuclear Silo)",
    "Nuke Launch",
    "Move&Paint Nuke Target",
    "Attack Unit (Nuke)",
    "Attack Ground (Nuke)",
    "Nuke Track (Ghost)",
    "Init Cloaking Field",
    "Cloaking Field",
    "Place Spider Mine",
    "Right Click Action",
    "Attack Unit (Infested Terran)",
    "Attack Ground (Infested Terran)",
    "Hold Position (Suicide Units)",
    "Cast Recall",
    "Recall to Location",
    "Cast Scanner Sweep",
    "Idle (Scanner Sweep)",
    "Cast Defensive Matrix",
    "Cast Psionic Storm",
    "Cast Irradiate",
    "Cast Plague",
    "Cast Consume",
    "Cast Ensnare",
    "Cast Stasis Field",
    "Cast Hallucination",
    "Kill Hallucination on Spell",
    "Reset Collision (2 Units)",
    "Reset Collision (Harvester&Mine)",
    "Patrol",
    "CTF COP (Initialize)",
    "Idle (CTF COP)",
    "Unknown CTF COP 2",
    "Script (Computer)",
    "Attack Move (Computer)",
    "Move (Harass)",
    "Patrol (Computer)",
    "Guard (Computer)",
    "Rescuable Passive",
    "Idle (Neutral)",
    "Return To Base (Computer)",
    "Init Psi Provider",
    "Fatal (Scarab)",
    "Idle (Critter)",
    "Hidden Trap",
    "Open Door",
    "Close Door",
    "Hide Trap",
    "Reveal Trap",
    "Enable Doodad",
    "Disable Doodad",
    "Warp In (Unused)",
    "Idle (Medic)",
    "Cast Heal",
    "Heal Move",
    "Hold Position&Heal",
    "Return To Idle After Heal",
    "Cast Restoration",
    "Cast Disruption Web",
    "Cast Mind Control",
    "Dark Archon Meld",
    "Cast Feedback",
    "Cast Optical Flare",
    "Cast Maelstrom",
    "Junk Yard Dog",
    "Fatal",
]
